import Foundation
import ITWebAPI
// MARK: Factory
open class BizcoupWebAPIContext : ITWebAPIContext{
	required public init(){}
    open var visitablePair:ITVisitablePair = ITXmlVisitablePair()
    open var secureKeys = [String:ITSecureKey]()
    open func setSecureKey(_ secureKey:ITSecureKey?) -> ITWebAPIContext?{
        if let secureKey_ = secureKey {
            secureKeys[secureKey_.name] = secureKey_
        }
        return self
    }

    open func getSecureKey(_ keyName:String) -> ITSecureKey? {
        return self.secureKeys[keyName]
    }

    open func getSecureKeys() -> [String:ITSecureKey]? {
        return self.secureKeys
    }

    open func createRequestBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody{
        if secureKey == nil {
            return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open func createResponseBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody {
        if secureKey == nil {
            return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open enum BodyType{
        case requestBody
        case responseBody
    }

    open func createBody(type:BodyType,requestMapping:String,content:String?,secureKeys:[String:ITSecureKey]) -> ITWebAPIBody{
        var body:ITWebAPIBody
        switch(requestMapping){
        				case "/api/coupon/business/getcouponlist":
				if type == .requestBody {
                    body = BizcoupPostCouponList()
                } else {
                    body = BizcoupRetCouponList(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/business/receivecoupon":
				if type == .requestBody {
                    body = BizcoupPostReceiveCoupon()
                } else {
                    body = BizcoupRetReceiveCoupon(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/business/receivecouponnotoken":
				if type == .requestBody {
                    body = BizcoupPostReceiveCouponNotoken()
                } else {
                    body = BizcoupRetReceiveCouponNotoken(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/business/reccouponexe":
				if type == .requestBody {
                    body = BizcoupPostRecCouponExe()
                } else {
                    body = BizcoupRetRecCouponExe(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/business/giveByCouponId":
				if type == .requestBody {
                    body = BizcoupPostGiveByCouponId()
                } else {
                    body = BizcoupRetGiveByCouponId(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/business/invitedCoupon":
				if type == .requestBody {
                    body = BizcoupPostInvitedCoupon()
                } else {
                    body = BizcoupRetInvitedCoupon(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/business/payMoney":
				if type == .requestBody {
                    body = BizcoupPostCoupPayMoney()
                } else {
                    body = BizcoupRetCoupPayMoney(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/business/percouponlist":
				if type == .requestBody {
                    body = BizcoupPostPerCouponList()
                } else {
                    body = BizcoupRetPerCouponList(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/business/updateCoupStatus":
				if type == .requestBody {
                    body = BizcoupPostUpdateCoupStatus()
                } else {
                    body = BizcoupRetUpdateCoupStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/business/cancelCoupUse":
				if type == .requestBody {
                    body = BizcoupPostCancelCoupUse()
                } else {
                    body = BizcoupRetCancelCoupUse(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/wallet/queryCoupUsedById":
				if type == .requestBody {
                    body = BizcoupPostQueryCoupUsedById()
                } else {
                    body = BizcoupRetQueryCoupUsedById(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/business/hzActivity":
				if type == .requestBody {
                    body = BizcoupPostHzActivity()
                } else {
                    body = BizcoupRetHzActivity(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/activity/nationalUserDraw":
				if type == .requestBody {
                    body = BizcoupPostNationalUserDraw()
                } else {
                    body = BizcoupRetNationalUserDraw(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/activity/getUserCardNum":
				if type == .requestBody {
                    body = BizcoupPostActivityUserCard()
                } else {
                    body = BizcoupRetActivityUserCard(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/activity/nationalDrawCoupon":
				if type == .requestBody {
                    body = BizcoupPostNationalDrawCoupon()
                } else {
                    body = BizcoupRetNationalDrawCoupon(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/activity/exchangeKingCard":
				if type == .requestBody {
                    body = BizcoupPostExchangeKingCard()
                } else {
                    body = BizcoupRetExchangeKingCard(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/activity/userOtherChance":
				if type == .requestBody {
                    body = BizcoupPostUserOtherChance()
                } else {
                    body = BizcoupRetUserOtherChance(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/activity/getUserDrawtime":
				if type == .requestBody {
                    body = BizcoupPostUserDrawtime()
                } else {
                    body = BizcoupRetUserDrawtime(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/wallet/userBuyWallet":
				if type == .requestBody {
                    body = BizcoupPostUserBuyWallet()
                } else {
                    body = BizcoupRetUserBuyWallet(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/wallet/queryUserWallet":
				if type == .requestBody {
                    body = BizcoupPostQueryUserWallet()
                } else {
                    body = BizcoupRetQueryUserWallet(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/wallet/queryWalletConfigList":
				if type == .requestBody {
                    body = BizcoupPostQueryWalletConfigList()
                } else {
                    body = BizcoupRetQueryWalletConfigList(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/wallet/getWalletBuyRecord":
				if type == .requestBody {
                    body = BizcoupPostGetWalletBuyRecord()
                } else {
                    body = BizcoupRetGetWalletBuyRecord(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/wallet/userWalletConsumeRecord":
				if type == .requestBody {
                    body = BizcoupPostUserWalletConsumeRecord()
                } else {
                    body = BizcoupRetUserWalletConsumeRecord(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/wallet/queryWalletConfigById":
				if type == .requestBody {
                    body = BizcoupPostQueryWalletConfigById()
                } else {
                    body = BizcoupRetQueryWalletConfigById(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/wallet/useWallet":
				if type == .requestBody {
                    body = BizcoupPostUseWallet()
                } else {
                    body = BizcoupRetUseWallet(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/wallet/walletRefund":
				if type == .requestBody {
                    body = BizcoupPostWalletRefund()
                } else {
                    body = BizcoupRetWalletRefund(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/business/getCoupUsedInfoById":
				if type == .requestBody {
                    body = BizcoupPostQueryCouponUsedInfo()
                } else {
                    body = BizcoupRetQueryUsedInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/sign/getSignListAndStatus":
				if type == .requestBody {
                    body = BizcoupPostSignListAndStatus()
                } else {
                    body = BizcoupRetSignListAndStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/sign/signForDD":
				if type == .requestBody {
                    body = BizcoupPostSignForDD()
                } else {
                    body = BizcoupRetSignForDD(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/redpac/userRedpac":
				if type == .requestBody {
                    body = BizcoupPostUserRedpac()
                } else {
                    body = BizcoupRetUserRedpac(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/redpac/getRedpacObtainRecord":
				if type == .requestBody {
                    body = BizcoupPostGetRedpacObtainRecord()
                } else {
                    body = BizcoupRetGetRedpacObtainRecord(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/redpac/useRedpacRecord":
				if type == .requestBody {
                    body = BizcoupPostUseRedpacRecord()
                } else {
                    body = BizcoupRetUseRedpacRecord(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/redpac/shiftToBanlance":
				if type == .requestBody {
                    body = BizcoupPostShiftToBanlance()
                } else {
                    body = BizcoupRetShiftToBanlance(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/redpac/redpacWithdraw":
				if type == .requestBody {
                    body = BizcoupPostRedpacWithdraw()
                } else {
                    body = BizcoupRetRedpacWithdraw(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/redpac/receiveRedpac":
				if type == .requestBody {
                    body = BizcoupPostReceiveRedpac()
                } else {
                    body = BizcoupRetReceiveRedpac(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/points/getMemberLevel":
				if type == .requestBody {
                    body = BizcoupPostMemberLevel()
                } else {
                    body = BizcoupRetMemberLevel(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/points/getMemberPoints":
				if type == .requestBody {
                    body = BizcoupPostMemberPoints()
                } else {
                    body = BizcoupRetMemberPoints(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/coupon/points/getMemberPointsRecord":
				if type == .requestBody {
                    body = BizcoupPostMemberPointsRecord()
                } else {
                    body = BizcoupRetMemberPointsRecord(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						default:
			body = BaseITWebAPIBody()
        }
        body.context = self
        return body
    }
}


		
open class BizcoupPostCouponList : BaseITWebAPIBody {
	
	//
						open var couponType:String?
    							open var usedCity:String?
    							open var devType:String?
    							open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/getcouponlist"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/getcouponlist"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let couponType_ = self.couponType;
																					let usedCity_ = self.usedCity;
																					let devType_ = self.devType;
																					let beginindex_ = self.beginindex;
																					let retcount_ = self.retcount;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostCouponList",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"couponType",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:couponType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"couponType",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"usedCity",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:usedCity_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"usedCity",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"devType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:devType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"devType",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"retcount",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostCouponList",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetCouponList : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizcoupCouponRecord]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/getcouponlist"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/getcouponlist"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( CouponRecord (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:CouponRecord) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [CouponRecord]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizcoupCouponRecord : BaseITWebAPIBody {
	
	//
						open var title:String?
    							open var couponType:String?
    							open var vaildStatTime:String?
    							open var vaildEndTime:String?
    							open var usedCity:String?
    							open var devType:String?
    							open var remarks:String?
    							open var imagePath:String?
    							open var money:String?
    							open var discount:String?
    							open var quantity:String?
    							open var status:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/getcouponlist"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/getcouponlist"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		title = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("title"))
																											couponType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("couponType"))
																											vaildStatTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("vaildStatTime"))
																											vaildEndTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("vaildEndTime"))
																											usedCity = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("usedCity"))
																											devType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("devType"))
																											remarks = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("remarks"))
																											imagePath = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("imagePath"))
																											money = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("money"))
																											discount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("discount"))
																											quantity = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("quantity"))
																											status = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("status"))
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizcoupPostReceiveCoupon : BaseITWebAPIBody {
	
	//
									open var couponId:String?
    							open var serviceId:String?
    							open var channl:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/receivecoupon"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/receivecoupon"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let couponId_ = self.couponId;
																					let serviceId_ = self.serviceId;
																					let channl_ = self.channl;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostReceiveCoupon",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"couponId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:couponId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"couponId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"channl",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:channl_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"channl",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostReceiveCoupon",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetReceiveCoupon : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/receivecoupon"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/receivecoupon"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostReceiveCouponNotoken : BaseITWebAPIBody {
	
	//
						open var userId:String?
    							open var phone:String?
    							open var couponId:String?
    							open var serviceId:String?
    							open var channl:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/receivecouponnotoken"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/receivecouponnotoken"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let userId_ = self.userId;
																					let phone_ = self.phone;
																					let couponId_ = self.couponId;
																					let serviceId_ = self.serviceId;
																					let channl_ = self.channl;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostReceiveCouponNotoken",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"userId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:userId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"userId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"phone",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:phone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"phone",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"couponId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:couponId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"couponId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"channl",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:channl_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"channl",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostReceiveCouponNotoken",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetReceiveCouponNotoken : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/receivecouponnotoken"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/receivecouponnotoken"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostRecCouponExe : BaseITWebAPIBody {
	
	//
									open var count:String?
    							open var pushFlag:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/reccouponexe"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/reccouponexe"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let count_ = self.count;
																					let pushFlag_ = self.pushFlag;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostRecCouponExe",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"count",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:count_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"count",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"pushFlag",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:pushFlag_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"pushFlag",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostRecCouponExe",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetRecCouponExe : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/reccouponexe"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/reccouponexe"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostGiveByCouponId : BaseITWebAPIBody {
	
	//
									open var couponId:String?
    							open var count:String?
    							open var pushFlag:String?
    							open var pushMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/giveByCouponId"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/giveByCouponId"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let couponId_ = self.couponId;
																					let count_ = self.count;
																					let pushFlag_ = self.pushFlag;
																					let pushMsg_ = self.pushMsg;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostGiveByCouponId",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"couponId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:couponId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"couponId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"count",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:count_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"count",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"pushFlag",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:pushFlag_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"pushFlag",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"pushMsg",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:pushMsg_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"pushMsg",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostGiveByCouponId",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetGiveByCouponId : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/giveByCouponId"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/giveByCouponId"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostInvitedCoupon : BaseITWebAPIBody {
	
	//
						open var fromUserId:String?
    							open var fromUserPhone:String?
    							open var toUserId:String?
    							open var toUserPhone:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/invitedCoupon"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/invitedCoupon"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let fromUserId_ = self.fromUserId;
																					let fromUserPhone_ = self.fromUserPhone;
																					let toUserId_ = self.toUserId;
																					let toUserPhone_ = self.toUserPhone;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostInvitedCoupon",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"fromUserId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:fromUserId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"fromUserId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"fromUserPhone",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:fromUserPhone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"fromUserPhone",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"toUserId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:toUserId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"toUserId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"toUserPhone",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:toUserPhone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"toUserPhone",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostInvitedCoupon",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetInvitedCoupon : BaseITWebAPIBody {
	
	//
												open var id:String?
    							open var title:String?
    							open var coupType:String?
    							open var validStartDate:String?
    							open var validEndDate:String?
    							open var usedCity:String?
    							open var devType:String?
    							open var remarks:String?
    							open var imagePath:String?
    							open var money:String?
    							open var useStatus:String?
    							open var total:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/invitedCoupon"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/invitedCoupon"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											id = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("id"))
																											title = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("title"))
																											coupType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coupType"))
																											validStartDate = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("validStartDate"))
																											validEndDate = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("validEndDate"))
																											usedCity = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("usedCity"))
																											devType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("devType"))
																											remarks = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("remarks"))
																											imagePath = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("imagePath"))
																											money = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("money"))
																											useStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("useStatus"))
																											total = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("total"))
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostCoupPayMoney : BaseITWebAPIBody {
	
	//
						open var couponId:String?
    							open var money:String?
    							open var hireDate:String?
    							open var restoreDate:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/payMoney"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/payMoney"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let couponId_ = self.couponId;
																					let money_ = self.money;
																					let hireDate_ = self.hireDate;
																					let restoreDate_ = self.restoreDate;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostCoupPayMoney",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"couponId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:couponId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"couponId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"money",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:money_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"money",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"hireDate",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:hireDate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"hireDate",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"restoreDate",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:restoreDate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"restoreDate",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostCoupPayMoney",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetCoupPayMoney : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var adjustMoney:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/payMoney"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/payMoney"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											adjustMoney = visitableSource.getValue("adjustMoney")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostPerCouponList : BaseITWebAPIBody {
	
	//
									open var couponClass:String?
    							open var couponType:String?
    							open var cycleType:String?
    							open var orderType:String?
    							open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/percouponlist"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/percouponlist"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let couponClass_ = self.couponClass;
																					let couponType_ = self.couponType;
																					let cycleType_ = self.cycleType;
																					let orderType_ = self.orderType;
																					let beginindex_ = self.beginindex;
																					let retcount_ = self.retcount;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostPerCouponList",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"couponClass",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:couponClass_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"couponClass",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"couponType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:couponType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"couponType",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"cycleType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:cycleType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"cycleType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"orderType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:orderType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"orderType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"retcount",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostPerCouponList",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetPerCouponList : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizcoupPerCouponRecord]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/percouponlist"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/percouponlist"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( PerCouponRecord (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:PerCouponRecord) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [PerCouponRecord]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizcoupPerCouponRecord : BaseITWebAPIBody {
	
	//
						open var id:String?
    							open var title:String?
    							open var couponType:String?
    							open var vaildStatTime:String?
    							open var vaildEndTime:String?
    							open var scope:String?
    							open var devType:String?
    							open var intro:String?
    							open var imagePath:String?
    							open var money:String?
    							open var discount:String?
    							open var useStatus:String?
    							open var couponStatus:String?
    							open var orderId:String?
    							open var coupClass:String?
    							open var qrCode:String?
    							open var sellerUsedRules:String?
    							open var sellerName:String?
    							open var sellerAddress:String?
    							open var sellerImg:String?
    							open var sellerPhone:String?
    							open var wechatAccounts:String?
    							open var businessStartHours:String?
    							open var businessEndHours:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/percouponlist"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/percouponlist"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		id = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("id"))
																											title = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("title"))
																											couponType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("couponType"))
																											vaildStatTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("vaildStatTime"))
																											vaildEndTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("vaildEndTime"))
																											scope = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("scope"))
																											devType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("devType"))
																											intro = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("intro"))
																											imagePath = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("imagePath"))
																											money = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("money"))
																											discount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("discount"))
																											useStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("useStatus"))
																											couponStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("couponStatus"))
																											orderId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderId"))
																											coupClass = visitableSource.getValue("coupClass")
																											qrCode = visitableSource.getValue("qrCode")
																											sellerUsedRules = visitableSource.getValue("sellerUsedRules")
																											sellerName = visitableSource.getValue("sellerName")
																											sellerAddress = visitableSource.getValue("sellerAddress")
																											sellerImg = visitableSource.getValue("sellerImg")
																											sellerPhone = visitableSource.getValue("sellerPhone")
																											wechatAccounts = visitableSource.getValue("wechatAccounts")
																											businessStartHours = visitableSource.getValue("businessStartHours")
																											businessEndHours = visitableSource.getValue("businessEndHours")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizcoupPostUpdateCoupStatus : BaseITWebAPIBody {
	
	//
						open var id:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/updateCoupStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/updateCoupStatus"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let id_ = self.id;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostUpdateCoupStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"id",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:id_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"id",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostUpdateCoupStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetUpdateCoupStatus : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/updateCoupStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/updateCoupStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostCancelCoupUse : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/cancelCoupUse"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/cancelCoupUse"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostCancelCoupUse",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"accessToken",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostCancelCoupUse",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetCancelCoupUse : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/cancelCoupUse"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/cancelCoupUse"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostQueryCoupUsedById : BaseITWebAPIBody {
	
	//
						open var id:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryCoupUsedById"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryCoupUsedById"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let id_ = self.id;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostQueryCoupUsedById",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"id",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:id_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"id",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostQueryCoupUsedById",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetQueryCoupUsedById : BaseITWebAPIBody {
	
	//
												open var couponType:String?
    							open var money:String?
    							open var discount:String?
    							open var hour:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryCoupUsedById"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryCoupUsedById"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											couponType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("couponType"))
																											money = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("money"))
																											discount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("discount"))
																											hour = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("hour"))
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostHzActivity : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/hzActivity"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/hzActivity"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostHzActivity",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"accessToken",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostHzActivity",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetHzActivity : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/hzActivity"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/hzActivity"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostNationalUserDraw : BaseITWebAPIBody {
	
	//
									open var drawChannl:String?
    							open var activityType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/nationalUserDraw"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/nationalUserDraw"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let drawChannl_ = self.drawChannl;
																					let activityType_ = self.activityType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostNationalUserDraw",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"drawChannl",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:drawChannl_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"drawChannl",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"activityType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:activityType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"activityType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostNationalUserDraw",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetNationalUserDraw : BaseITWebAPIBody {
	
	//
												open var cardNo:String?
    							open var cardName:String?
    							open var isDraw:String?
    							open var coupTitle:String?
    							open var coupNum:String?
    							open var coupId:String?
    							open var remaindTimes:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/nationalUserDraw"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/nationalUserDraw"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											cardNo = visitableSource.getValue("cardNo")
																											cardName = visitableSource.getValue("cardName")
																											isDraw = visitableSource.getValue("isDraw")
																											coupTitle = visitableSource.getValue("coupTitle")
																											coupNum = visitableSource.getValue("coupNum")
																											coupId = visitableSource.getValue("coupId")
																											remaindTimes = visitableSource.getValue("remaindTimes")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostActivityUserCard : BaseITWebAPIBody {
	
	//
									open var activityType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/getUserCardNum"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/getUserCardNum"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let activityType_ = self.activityType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostActivityUserCard",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"activityType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:activityType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"activityType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostActivityUserCard",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetActivityUserCard : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    							open var time:String?
    				    		//----->list
			fileprivate var data = [BizcoupUserCard]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/getUserCardNum"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/getUserCardNum"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																											time = visitableSource.getValue("time")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( UserCard (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    		    			    open func addData(subBody:UserCard) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [UserCard]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																													
open class BizcoupUserCard : BaseITWebAPIBody {
	
	//
						open var id:String?
    							open var cardId:String?
    							open var cardNo:String?
    							open var cardName:String?
    							open var coupId:String?
    							open var coupNum:String?
    							open var coupTitle:String?
    							open var isDraw:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/getUserCardNum"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/getUserCardNum"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		id = visitableSource.getValue("id")
																											cardId = visitableSource.getValue("cardId")
																											cardNo = visitableSource.getValue("cardNo")
																											cardName = visitableSource.getValue("cardName")
																											coupId = visitableSource.getValue("coupId")
																											coupNum = visitableSource.getValue("coupNum")
																											coupTitle = visitableSource.getValue("coupTitle")
																											isDraw = visitableSource.getValue("isDraw")
															}

	//-------> list
			    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizcoupPostNationalDrawCoupon : BaseITWebAPIBody {
	
	//
									open var cardCouponId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/nationalDrawCoupon"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/nationalDrawCoupon"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let cardCouponId_ = self.cardCouponId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostNationalDrawCoupon",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"cardCouponId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:cardCouponId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"cardCouponId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostNationalDrawCoupon",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetNationalDrawCoupon : BaseITWebAPIBody {
	
	//
												open var cardNo:String?
    							open var cardName:String?
    							open var isDraw:String?
    							open var coupId:String?
    							open var coupNum:String?
    							open var coupTitle:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/nationalDrawCoupon"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/nationalDrawCoupon"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											cardNo = visitableSource.getValue("cardNo")
																											cardName = visitableSource.getValue("cardName")
																											isDraw = visitableSource.getValue("isDraw")
																											coupId = visitableSource.getValue("coupId")
																											coupNum = visitableSource.getValue("coupNum")
																											coupTitle = visitableSource.getValue("coupTitle")
															}

	//-------> list
			    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostExchangeKingCard : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/exchangeKingCard"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/exchangeKingCard"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostExchangeKingCard",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"accessToken",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostExchangeKingCard",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetExchangeKingCard : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/exchangeKingCard"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/exchangeKingCard"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostUserOtherChance : BaseITWebAPIBody {
	
	//
									open var channl:String?
    							open var activityType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/userOtherChance"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/userOtherChance"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let channl_ = self.channl;
																					let activityType_ = self.activityType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostUserOtherChance",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"channl",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:channl_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"channl",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"activityType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:activityType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"activityType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostUserOtherChance",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetUserOtherChance : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/userOtherChance"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/userOtherChance"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostUserDrawtime : BaseITWebAPIBody {
	
	//
									open var activityType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/getUserDrawtime"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/getUserDrawtime"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let activityType_ = self.activityType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostUserDrawtime",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"activityType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:activityType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"activityType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostUserDrawtime",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetUserDrawtime : BaseITWebAPIBody {
	
	//
												open var time:String?
    							open var sharedTimes:String?
    							open var cyclingTimes:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/getUserDrawtime"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/activity/getUserDrawtime"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											time = visitableSource.getValue("time")
																											sharedTimes = visitableSource.getValue("sharedTimes")
																											cyclingTimes = visitableSource.getValue("cyclingTimes")
															}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostUserBuyWallet : BaseITWebAPIBody {
	
	//
									open var walletConfigId:String?
    							open var appId:String?
    							open var serviceId:String?
    							open var orderId:String?
    							open var rechargeChannel:String?
    							open var buyChannel:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/userBuyWallet"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/userBuyWallet"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let walletConfigId_ = self.walletConfigId;
																					let appId_ = self.appId;
																					let serviceId_ = self.serviceId;
																					let orderId_ = self.orderId;
																					let rechargeChannel_ = self.rechargeChannel;
																					let buyChannel_ = self.buyChannel;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostUserBuyWallet",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"walletConfigId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:walletConfigId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"walletConfigId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"orderId",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"rechargeChannel",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:rechargeChannel_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"rechargeChannel",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"buyChannel",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:buyChannel_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"buyChannel",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostUserBuyWallet",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetUserBuyWallet : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/userBuyWallet"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/userBuyWallet"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											orderId = visitableSource.getValue("orderId")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostQueryUserWallet : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryUserWallet"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryUserWallet"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostQueryUserWallet",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"serviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostQueryUserWallet",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetQueryUserWallet : BaseITWebAPIBody {
	
	//
												open var money:String?
    							open var giveMoney:String?
    							open var lockStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryUserWallet"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryUserWallet"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											money = visitableSource.getValue("money")
																											giveMoney = visitableSource.getValue("giveMoney")
																											lockStatus = visitableSource.getValue("lockStatus")
															}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostQueryWalletConfigList : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryWalletConfigList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryWalletConfigList"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = self.appId;
																					let serviceId_ = self.serviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostQueryWalletConfigList",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"serviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostQueryWalletConfigList",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetQueryWalletConfigList : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizcoupGetWalletConfigList]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryWalletConfigList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryWalletConfigList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( GetWalletConfigList (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:GetWalletConfigList) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [GetWalletConfigList]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizcoupGetWalletConfigList : BaseITWebAPIBody {
	
	//
						open var id:String?
    							open var money:String?
    							open var giveMoney:String?
    							open var order:String?
    							open var recommend:String?
    							open var remark:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryWalletConfigList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryWalletConfigList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		id = visitableSource.getValue("id")
																											money = visitableSource.getValue("money")
																											giveMoney = visitableSource.getValue("giveMoney")
																											order = visitableSource.getValue("order")
																											recommend = visitableSource.getValue("recommend")
																											remark = visitableSource.getValue("remark")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizcoupPostGetWalletBuyRecord : BaseITWebAPIBody {
	
	//
									open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/getWalletBuyRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/getWalletBuyRecord"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let beginindex_ = self.beginindex;
																					let retcount_ = self.retcount;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostGetWalletBuyRecord",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"retcount",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostGetWalletBuyRecord",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetGetWalletBuyRecord : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizcoupGetWalletBuyRecord]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/getWalletBuyRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/getWalletBuyRecord"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( GetWalletBuyRecord (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:GetWalletBuyRecord) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [GetWalletBuyRecord]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizcoupGetWalletBuyRecord : BaseITWebAPIBody {
	
	//
						open var money:String?
    							open var giveMoney:String?
    							open var walletConfigName:String?
    							open var createTime:String?
    							open var rechargeChannel:String?
    							open var buyChannel:String?
    							open var flag:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/getWalletBuyRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/getWalletBuyRecord"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		money = visitableSource.getValue("money")
																											giveMoney = visitableSource.getValue("giveMoney")
																											walletConfigName = visitableSource.getValue("walletConfigName")
																											createTime = visitableSource.getValue("createTime")
																											rechargeChannel = visitableSource.getValue("rechargeChannel")
																											buyChannel = visitableSource.getValue("buyChannel")
																											flag = visitableSource.getValue("flag")
															}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizcoupPostUserWalletConsumeRecord : BaseITWebAPIBody {
	
	//
									open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/userWalletConsumeRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/userWalletConsumeRecord"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let beginindex_ = self.beginindex;
																					let retcount_ = self.retcount;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostUserWalletConsumeRecord",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"retcount",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostUserWalletConsumeRecord",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetUserWalletConsumeRecord : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizcoupUserWalletConsumeRecord]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/userWalletConsumeRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/userWalletConsumeRecord"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( UserWalletConsumeRecord (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:UserWalletConsumeRecord) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [UserWalletConsumeRecord]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizcoupUserWalletConsumeRecord : BaseITWebAPIBody {
	
	//
						open var bikeType:String?
    							open var usedTime:String?
    							open var totalUsedMoney:String?
    							open var usedChannel:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/userWalletConsumeRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/userWalletConsumeRecord"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		bikeType = visitableSource.getValue("bikeType")
																											usedTime = visitableSource.getValue("usedTime")
																											totalUsedMoney = visitableSource.getValue("totalUsedMoney")
																											usedChannel = visitableSource.getValue("usedChannel")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizcoupPostQueryWalletConfigById : BaseITWebAPIBody {
	
	//
									open var walletConfigId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryWalletConfigById"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryWalletConfigById"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let walletConfigId_ = self.walletConfigId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostQueryWalletConfigById",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"walletConfigId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:walletConfigId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"walletConfigId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostQueryWalletConfigById",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetQueryWalletConfigById : BaseITWebAPIBody {
	
	//
												open var money:String?
    							open var giveMoney:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryWalletConfigById"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/queryWalletConfigById"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											money = visitableSource.getValue("money")
																											giveMoney = visitableSource.getValue("giveMoney")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostUseWallet : BaseITWebAPIBody {
	
	//
									open var moeny:String?
    							open var tripId:String?
    							open var serviceId:String?
    							open var bikeType:String?
    							open var usedChannel:String?
    							open var payOrderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/useWallet"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/useWallet"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let moeny_ = self.moeny;
																					let tripId_ = self.tripId;
																					let serviceId_ = self.serviceId;
																					let bikeType_ = self.bikeType;
																					let usedChannel_ = self.usedChannel;
																					let payOrderId_ = self.payOrderId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostUseWallet",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"moeny",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:moeny_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"moeny",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"tripId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:tripId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"tripId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"bikeType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:bikeType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"bikeType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"usedChannel",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:usedChannel_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"usedChannel",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"payOrderId",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:payOrderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"payOrderId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostUseWallet",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetUseWallet : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/useWallet"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/useWallet"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostWalletRefund : BaseITWebAPIBody {
	
	//
									open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/walletRefund"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/walletRefund"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let orderId_ = self.orderId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostWalletRefund",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"orderId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostWalletRefund",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetWalletRefund : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/walletRefund"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/wallet/walletRefund"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostQueryCouponUsedInfo : BaseITWebAPIBody {
	
	//
									open var couponId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/getCoupUsedInfoById"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/getCoupUsedInfoById"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let couponId_ = self.couponId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostQueryCouponUsedInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"couponId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:couponId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"couponId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostQueryCouponUsedInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetQueryUsedInfo : BaseITWebAPIBody {
	
	//
												open var money:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/getCoupUsedInfoById"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/business/getCoupUsedInfoById"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											money = visitableSource.getValue("money")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostSignListAndStatus : BaseITWebAPIBody {
	
	//
									open var signId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/sign/getSignListAndStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/sign/getSignListAndStatus"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let signId_ = self.signId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostSignListAndStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"signId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:signId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"signId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostSignListAndStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetSignListAndStatus : BaseITWebAPIBody {
	
	//
												open var signFlag:String?
    							open var signArray:String?
    							open var coinNum:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/sign/getSignListAndStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/sign/getSignListAndStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											signFlag = visitableSource.getValue("signFlag")
																											signArray = visitableSource.getValue("signArray")
																											coinNum = visitableSource.getValue("coinNum")
															}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostSignForDD : BaseITWebAPIBody {
	
	//
									open var signId:String?
    							open var serviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/sign/signForDD"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/sign/signForDD"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let signId_ = self.signId;
																					let serviceId_ = self.serviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostSignForDD",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"signId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:signId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"signId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"serviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostSignForDD",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetSignForDD : BaseITWebAPIBody {
	
	//
												open var signFlag:String?
    							open var signArray:String?
    							open var coinNum:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/sign/signForDD"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/sign/signForDD"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											signFlag = visitableSource.getValue("signFlag")
																											signArray = visitableSource.getValue("signArray")
																											coinNum = visitableSource.getValue("coinNum")
															}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostUserRedpac : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/userRedpac"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/userRedpac"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostUserRedpac",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"serviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostUserRedpac",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetUserRedpac : BaseITWebAPIBody {
	
	//
												open var redpacMoney:String?
    							open var obtainedCash:String?
    							open var withdrawRedpac:String?
    							open var lockStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/userRedpac"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/userRedpac"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											redpacMoney = visitableSource.getValue("redpacMoney")
																											obtainedCash = visitableSource.getValue("obtainedCash")
																											withdrawRedpac = visitableSource.getValue("withdrawRedpac")
																											lockStatus = visitableSource.getValue("lockStatus")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostGetRedpacObtainRecord : BaseITWebAPIBody {
	
	//
									open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/getRedpacObtainRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/getRedpacObtainRecord"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let beginindex_ = self.beginindex;
																					let retcount_ = self.retcount;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostGetRedpacObtainRecord",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"retcount",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostGetRedpacObtainRecord",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetGetRedpacObtainRecord : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizcoupRedpacObtainRecord]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/getRedpacObtainRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/getRedpacObtainRecord"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RedpacObtainRecord (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:RedpacObtainRecord) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RedpacObtainRecord]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizcoupRedpacObtainRecord : BaseITWebAPIBody {
	
	//
						open var obtainRedpac:String?
    							open var obtainChannel:String?
    							open var createTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/getRedpacObtainRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/getRedpacObtainRecord"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		obtainRedpac = visitableSource.getValue("obtainRedpac")
																											obtainChannel = visitableSource.getValue("obtainChannel")
																											createTime = visitableSource.getValue("createTime")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizcoupPostUseRedpacRecord : BaseITWebAPIBody {
	
	//
									open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/useRedpacRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/useRedpacRecord"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let beginindex_ = self.beginindex;
																					let retcount_ = self.retcount;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostUseRedpacRecord",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"retcount",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostUseRedpacRecord",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetUseRedpacRecord : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizcoupUseRedpacRecord]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/useRedpacRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/useRedpacRecord"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( UseRedpacRecord (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:UseRedpacRecord) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [UseRedpacRecord]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizcoupUseRedpacRecord : BaseITWebAPIBody {
	
	//
						open var useChannel:String?
    							open var useRedpacNum:String?
    							open var createTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/useRedpacRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/useRedpacRecord"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		useChannel = visitableSource.getValue("useChannel")
																											useRedpacNum = visitableSource.getValue("useRedpacNum")
																											createTime = visitableSource.getValue("createTime")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizcoupPostShiftToBanlance : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/shiftToBanlance"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/shiftToBanlance"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostShiftToBanlance",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"serviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostShiftToBanlance",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetShiftToBanlance : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/shiftToBanlance"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/shiftToBanlance"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostRedpacWithdraw : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var money:String?
    							open var withdrawAccount:String?
    							open var userName:String?
    							open var accountFalg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/redpacWithdraw"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/redpacWithdraw"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
																					let money_ = self.money;
																					let withdrawAccount_ = self.withdrawAccount;
																					let userName_ = self.userName;
																					let accountFalg_ = self.accountFalg;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostRedpacWithdraw",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:7,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:7,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:7,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:7,field:"money",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:7,value:money_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:7,field:"money",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:7,field:"withdrawAccount",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:7,value:withdrawAccount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:7,field:"withdrawAccount",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:7,field:"userName",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:7,value:userName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:7,field:"userName",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:7,field:"accountFalg",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:7,value:accountFalg_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:7,field:"accountFalg",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostRedpacWithdraw",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetRedpacWithdraw : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/redpacWithdraw"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/redpacWithdraw"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostReceiveRedpac : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var obtainChannel:String?
    							open var redpacPerc:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/receiveRedpac"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/receiveRedpac"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
																					let obtainChannel_ = self.obtainChannel;
																					let redpacPerc_ = self.redpacPerc;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostReceiveRedpac",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"obtainChannel",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:obtainChannel_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"obtainChannel",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"redpacPerc",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:redpacPerc_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"redpacPerc",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostReceiveRedpac",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetReceiveRedpac : BaseITWebAPIBody {
	
	//
												open var obtainRedpac:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/receiveRedpac"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/redpac/receiveRedpac"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											obtainRedpac = visitableSource.getValue("obtainRedpac")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostMemberLevel : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberLevel"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberLevel"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostMemberLevel",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"accessToken",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostMemberLevel",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetMemberLevel : BaseITWebAPIBody {
	
	//
			    		//----->list
			fileprivate var data = [BizcoupMemberLevel]()
			//>-----
									
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberLevel"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberLevel"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
												//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( MemberLevel (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
																						retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
				    open func addData(subBody:MemberLevel) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [MemberLevel]{
	        return data
	    }
	        		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    									
open class BizcoupMemberLevel : BaseITWebAPIBody {
	
	//
						open var level:String?
    							open var levelName:String?
    							open var levelPoints:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberLevel"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberLevel"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		level = visitableSource.getValue("level")
																											levelName = visitableSource.getValue("levelName")
																											levelPoints = visitableSource.getValue("levelPoints")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
																}

		
open class BizcoupPostMemberPoints : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberPoints"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberPoints"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostMemberPoints",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"accessToken",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostMemberPoints",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetMemberPoints : BaseITWebAPIBody {
	
	//
						open var totalPoints:String?
    							open var userPoints:String?
    							open var createTime:String?
    							open var invalidTime:String?
    								
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberPoints"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberPoints"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		totalPoints = visitableSource.getValue("totalPoints")
																											userPoints = visitableSource.getValue("userPoints")
																											createTime = visitableSource.getValue("createTime")
																											invalidTime = visitableSource.getValue("invalidTime")
																											retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizcoupPostMemberPointsRecord : BaseITWebAPIBody {
	
	//
									open var start:String?
    							open var limit:String?
    							open var addOrSubtract:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberPointsRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberPointsRecord"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let start_ = self.start;
																					let limit_ = self.limit;
																					let addOrSubtract_ = self.addOrSubtract;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizcoupPostMemberPointsRecord",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"start",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:start_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"start",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"limit",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:limit_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"limit",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"addOrSubtract",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:addOrSubtract_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"addOrSubtract",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizcoupPostMemberPointsRecord",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizcoupRetMemberPointsRecord : BaseITWebAPIBody {
	
	//
			    		//----->list
			fileprivate var data = [BizcoupPointsRecord]()
			//>-----
									
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberPointsRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberPointsRecord"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
												//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( PointsRecord (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
																						retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
				    open func addData(subBody:PointsRecord) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [PointsRecord]{
	        return data
	    }
	        		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    									
open class BizcoupPointsRecord : BaseITWebAPIBody {
	
	//
						open var actionName:String?
    							open var actionPoints:String?
    							open var actionDate:String?
    		
	required public init(){
		super.init()
		self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberPointsRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "40"
		self.appName_ = "bizcoup"
		self.mapping_ = "/api/coupon/points/getMemberPointsRecord"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		actionName = visitableSource.getValue("actionName")
																											actionPoints = visitableSource.getValue("actionPoints")
																											actionDate = visitableSource.getValue("actionDate")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
																}
