import Foundation
import ITWebAPI
// MARK: Factory
open class IotcaWebAPIContext : ITWebAPIContext{
	required public init(){}
    open var visitablePair:ITVisitablePair = ITXmlVisitablePair()
    open var secureKeys = [String:ITSecureKey]()
    open func setSecureKey(_ secureKey:ITSecureKey?) -> ITWebAPIContext?{
        if let secureKey_ = secureKey {
            secureKeys[secureKey_.name] = secureKey_
        }
        return self
    }

    open func getSecureKey(_ keyName:String) -> ITSecureKey? {
        return self.secureKeys[keyName]
    }

    open func getSecureKeys() -> [String:ITSecureKey]? {
        return self.secureKeys
    }

    open func createRequestBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody{
        if secureKey == nil {
            return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open func createResponseBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody {
        if secureKey == nil {
            return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open enum BodyType{
        case requestBody
        case responseBody
    }

    open func createBody(type:BodyType,requestMapping:String,content:String?,secureKeys:[String:ITSecureKey]) -> ITWebAPIBody{
        var body:ITWebAPIBody
        switch(requestMapping){
        				case "/api/iotca/business/hirerequest":
				if type == .requestBody {
                    body = IotcaPostIotHireRequest()
                } else {
                    body = IotcaRetIotHireRequest(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/iottrip":
				if type == .requestBody {
                    body = IotcaPostIotTrip()
                } else {
                    body = IotcaRetIotTrip(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/restorerequest":
				if type == .requestBody {
                    body = IotcaPostIotRestoreRequest()
                } else {
                    body = IotcaRetIotRestoreRequest(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/unlock":
				if type == .requestBody {
                    body = IotcaPostIotUnlock()
                } else {
                    body = IotcaRetIotUnlock(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/querydevices":
				if type == .requestBody {
                    body = IotcaPostQueryIotDevices()
                } else {
                    body = IotcaRetQueryIotDevices(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/querySupDevices":
				if type == .requestBody {
                    body = IotcaPostQuerySupDevices()
                } else {
                    body = IotcaRetQuerySupDevices(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/supErrorRestore":
				if type == .requestBody {
                    body = IotcaPostErrorRestore()
                } else {
                    body = IotcaRetErrorRestore(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/bhtSwitch":
				if type == .requestBody {
                    body = IotcaPostBhtSwitch()
                } else {
                    body = IotcaRetBhtSwitch(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/lockHeartBeat":
				if type == .requestBody {
                    body = IotcaPostLockHeartBeat()
                } else {
                    body = IotcaRetLockHeartBeat(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/setDeviceId":
				if type == .requestBody {
                    body = IotcaPostSetDeviceId()
                } else {
                    body = IotcaRetSetDeviceId(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/notifyUpgrade":
				if type == .requestBody {
                    body = IotcaPostNotifyUpgrade()
                } else {
                    body = IotcaRetNotifyUpgrade(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/supplementTrip":
				if type == .requestBody {
                    body = IotcaPostSupplementTrip()
                } else {
                    body = IotcaRetSupplementTrip(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/getLockPwd":
				if type == .requestBody {
                    body = IotcaPostGetLockPwd()
                } else {
                    body = IotcaRetGetLockPwd(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/timeCorrect":
				if type == .requestBody {
                    body = IotcaPostTimeCorrect()
                } else {
                    body = IotcaRetTimeCorrect(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/currentAmount":
				if type == .requestBody {
                    body = IotcaPostCurrentAmount()
                } else {
                    body = IotcaRetCurrentAmount(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/cmdLock":
				if type == .requestBody {
                    body = IotcaPostCmdLock()
                } else {
                    body = IotcaRetCmdLock(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/lockStatusCmd":
				if type == .requestBody {
                    body = IotcaPostLockStatusCmd()
                } else {
                    body = IotcaRetLockStatusCmd(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/currencyPush":
				if type == .requestBody {
                    body = IotcaPostCurrencyPush()
                } else {
                    body = IotcaRetCurrencyPush(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/pushOntMsg":
				if type == .requestBody {
                    body = IotcaPostPushOntMsg()
                } else {
                    body = IotcaRetPushOntMsg(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/ontPileHeartbeat":
				if type == .requestBody {
                    body = IotcaPostOntPileHeartbeat()
                } else {
                    body = IotcaRetOntPileHeartbeat(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/confirmTheLock":
				if type == .requestBody {
                    body = IotcaPostConfirmTheLock()
                } else {
                    body = IotcaRetConfirmTheLock(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/rentBikeFault":
				if type == .requestBody {
                    body = IotcaPostRentBikeFault()
                } else {
                    body = IotcaRetRentBikeFault(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/returnBikeReq":
				if type == .requestBody {
                    body = IotcaPostReturnBikeReq()
                } else {
                    body = IotcaRetReturnBikeReq(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/sendOutMqReq":
				if type == .requestBody {
                    body = IotcaPostSendOutMqReq()
                } else {
                    body = IotcaRetSendOutMqReq(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/upgradNnotify":
				if type == .requestBody {
                    body = IotcaPostUpgradNnotify()
                } else {
                    body = IotcaRetUpgradNnotify(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/audioUpgrade":
				if type == .requestBody {
                    body = IotcaPostAudioUpgrade()
                } else {
                    body = IotcaRetAudioUpgrade(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/iotForwardConfig":
				if type == .requestBody {
                    body = IotcaPostForwardConfig()
                } else {
                    body = IotcaRetForwardConfig(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/repayBikeLocReq":
				if type == .requestBody {
                    body = IotcaPostRepayBikeLocReq()
                } else {
                    body = IotcaRetRepayBikeLocReq(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/cp4ConfigDown":
				if type == .requestBody {
                    body = IotcaPostCp4ConfigDown()
                } else {
                    body = IotcaRetCp4ConfigDown(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/iotca/business/faultreturnbike":
				if type == .requestBody {
                    body = IotcaPostFaultReturnBike()
                } else {
                    body = IotcaRetFaultReturnBike(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						default:
			body = BaseITWebAPIBody()
        }
        body.context = self
        return body
    }
}


		
open class IotcaPostIotHireRequest : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var terminalType:String?
    							open var requestType:String?
    							open var DeviceId:String?
    							open var cityCode:String?
    							open var parkNum:String?
    							open var bizType:String?
    							open var deviceStakeId:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var version:String?
    							open var deviceType:String?
    							open var openId:String?
    							open var formId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/hirerequest"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/hirerequest"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let terminalType_ = secureKeys?["AES"]?.encrypt(original: self.terminalType) ?? ""
																					let requestType_ = secureKeys?["AES"]?.encrypt(original: self.requestType) ?? ""
																					let DeviceId_ = secureKeys?["AES"]?.encrypt(original: self.DeviceId) ?? ""
																					let cityCode_ = self.cityCode;
																					let parkNum_ = secureKeys?["AES"]?.encrypt(original: self.parkNum) ?? ""
																					let bizType_ = self.bizType;
																					let deviceStakeId_ = self.deviceStakeId;
																					let coordinate_ = self.coordinate;
																					let coordType_ = self.coordType;
																					let version_ = self.version;
																					let deviceType_ = self.deviceType;
																					let openId_ = self.openId;
																					let formId_ = self.formId;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&terminalType=" + (terminalType_ ?? ""))
																					md5.append("&requestType=" + (requestType_ ?? ""))
																					md5.append("&DeviceId=" + (DeviceId_ ?? ""))
																												md5.append("&parkNum=" + (parkNum_ ?? ""))
																																																																						
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostIotHireRequest",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:17,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:17,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:17,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:17,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:17,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:17,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:17,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:17,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:17,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:17,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:17,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:17,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:17,field:"requestType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:17,value:requestType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:17,field:"requestType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:17,field:"DeviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:17,value:DeviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:17,field:"DeviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:17,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:17,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:17,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:17,field:"parkNum",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:17,value:parkNum_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:17,field:"parkNum",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:17,field:"bizType",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:17,value:bizType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:17,field:"bizType",body:self))
												result.append(vo.onFieldBegin(.flat,index:10,length:17,field:"deviceStakeId",body:self))
				result.append(vo.onFieldValue(.flat,index:10,length:17,value:deviceStakeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:10,length:17,field:"deviceStakeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:11,length:17,field:"coordinate",body:self))
				result.append(vo.onFieldValue(.flat,index:11,length:17,value:coordinate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:11,length:17,field:"coordinate",body:self))
												result.append(vo.onFieldBegin(.flat,index:12,length:17,field:"coordType",body:self))
				result.append(vo.onFieldValue(.flat,index:12,length:17,value:coordType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:12,length:17,field:"coordType",body:self))
												result.append(vo.onFieldBegin(.flat,index:13,length:17,field:"version",body:self))
				result.append(vo.onFieldValue(.flat,index:13,length:17,value:version_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:13,length:17,field:"version",body:self))
												result.append(vo.onFieldBegin(.flat,index:14,length:17,field:"deviceType",body:self))
				result.append(vo.onFieldValue(.flat,index:14,length:17,value:deviceType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:14,length:17,field:"deviceType",body:self))
												result.append(vo.onFieldBegin(.flat,index:15,length:17,field:"openId",body:self))
				result.append(vo.onFieldValue(.flat,index:15,length:17,value:openId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:15,length:17,field:"openId",body:self))
												result.append(vo.onFieldBegin(.flat,index:16,length:17,field:"formId",body:self))
				result.append(vo.onFieldValue(.flat,index:16,length:17,value:formId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:16,length:17,field:"formId",body:self))
									result.append(vo.onFieldBegin(.flat,index:17,length:17,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:17,length:17,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:17,length:17,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostIotHireRequest",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetIotHireRequest : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    							open var reqStatus:String?
    							open var serviceId:String?
    							open var orderId:String?
    							open var bikeId:String?
    							open var reqExtra:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/hirerequest"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/hirerequest"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
																											reqStatus = visitableSource.getValue("reqStatus")
																											serviceId = visitableSource.getValue("serviceId")
																											orderId = visitableSource.getValue("orderId")
																											bikeId = visitableSource.getValue("bikeId")
																											reqExtra = visitableSource.getValue("reqExtra")
															}

	//-------> list
			    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostIotTrip : BaseITWebAPIBody {
	
	//
						open var dataType:String?
    							open var deviceId:String?
    							open var cityCode:String?
    							open var deviceType:String?
    							open var lockStatus:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var bizExtra:String?
    							open var batteryLevel:String?
    							open var deviceStakeId:String?
    							open var DataTime:String?
    							open var nailVersion:String?
    							open var nailBatter:String?
    							open var nailMAC:String?
    							open var nailNum:String?
    							open var liveStatus:String?
    							open var uniqueMessageId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/iottrip"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/iottrip"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let dataType_ = self.dataType;
																					let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
																					let deviceType_ = self.deviceType;
																					let lockStatus_ = self.lockStatus;
																					let coordinate_ = secureKeys?["AES"]?.encrypt(original: self.coordinate) ?? ""
																					let coordType_ = self.coordType;
																					let bizExtra_ = self.bizExtra;
																					let batteryLevel_ = self.batteryLevel;
																					let deviceStakeId_ = self.deviceStakeId;
																					let DataTime_ = secureKeys?["AES"]?.encrypt(original: self.DataTime) ?? ""
																					let nailVersion_ = self.nailVersion;
																					let nailBatter_ = self.nailBatter;
																					let nailMAC_ = self.nailMAC;
																					let nailNum_ = self.nailNum;
																					let liveStatus_ = self.liveStatus;
																					let uniqueMessageId_ = self.uniqueMessageId;
									
		//====   md5 check   ====
					var md5:[String] = []
																																																		md5.append("coordinate=" + (coordinate_ ?? ""))
																																																	md5.append("&DataTime=" + (DataTime_ ?? ""))
																																																								
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostIotTrip",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:18,field:"dataType",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:18,value:dataType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:18,field:"dataType",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:18,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:18,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:18,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:18,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:18,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:18,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:18,field:"deviceType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:18,value:deviceType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:18,field:"deviceType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:18,field:"lockStatus",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:18,value:lockStatus_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:18,field:"lockStatus",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:18,field:"coordinate",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:18,value:coordinate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:18,field:"coordinate",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:18,field:"coordType",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:18,value:coordType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:18,field:"coordType",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:18,field:"bizExtra",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:18,value:bizExtra_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:18,field:"bizExtra",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:18,field:"batteryLevel",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:18,value:batteryLevel_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:18,field:"batteryLevel",body:self))
												result.append(vo.onFieldBegin(.flat,index:10,length:18,field:"deviceStakeId",body:self))
				result.append(vo.onFieldValue(.flat,index:10,length:18,value:deviceStakeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:10,length:18,field:"deviceStakeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:11,length:18,field:"DataTime",body:self))
				result.append(vo.onFieldValue(.flat,index:11,length:18,value:DataTime_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:11,length:18,field:"DataTime",body:self))
												result.append(vo.onFieldBegin(.flat,index:12,length:18,field:"nailVersion",body:self))
				result.append(vo.onFieldValue(.flat,index:12,length:18,value:nailVersion_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:12,length:18,field:"nailVersion",body:self))
												result.append(vo.onFieldBegin(.flat,index:13,length:18,field:"nailBatter",body:self))
				result.append(vo.onFieldValue(.flat,index:13,length:18,value:nailBatter_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:13,length:18,field:"nailBatter",body:self))
												result.append(vo.onFieldBegin(.flat,index:14,length:18,field:"nailMAC",body:self))
				result.append(vo.onFieldValue(.flat,index:14,length:18,value:nailMAC_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:14,length:18,field:"nailMAC",body:self))
												result.append(vo.onFieldBegin(.flat,index:15,length:18,field:"nailNum",body:self))
				result.append(vo.onFieldValue(.flat,index:15,length:18,value:nailNum_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:15,length:18,field:"nailNum",body:self))
												result.append(vo.onFieldBegin(.flat,index:16,length:18,field:"liveStatus",body:self))
				result.append(vo.onFieldValue(.flat,index:16,length:18,value:liveStatus_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:16,length:18,field:"liveStatus",body:self))
												result.append(vo.onFieldBegin(.flat,index:17,length:18,field:"uniqueMessageId",body:self))
				result.append(vo.onFieldValue(.flat,index:17,length:18,value:uniqueMessageId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:17,length:18,field:"uniqueMessageId",body:self))
									result.append(vo.onFieldBegin(.flat,index:18,length:18,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:18,length:18,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:18,length:18,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostIotTrip",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetIotTrip : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/iottrip"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/iottrip"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostIotRestoreRequest : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    							open var deviceType:String?
    							open var lockStatus:String?
    							open var bizExtra:String?
    							open var DataTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/restorerequest"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/restorerequest"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
																					let deviceType_ = self.deviceType;
																					let lockStatus_ = self.lockStatus;
																					let bizExtra_ = self.bizExtra;
																					let DataTime_ = secureKeys?["AES"]?.encrypt(original: self.DataTime) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
																																																		md5.append("DataTime=" + (DataTime_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostIotRestoreRequest",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:7,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:7,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:7,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:7,field:"deviceType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:7,value:deviceType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:7,field:"deviceType",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:7,field:"lockStatus",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:7,value:lockStatus_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:7,field:"lockStatus",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:7,field:"bizExtra",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:7,value:bizExtra_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:7,field:"bizExtra",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:7,field:"DataTime",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:7,value:DataTime_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:7,field:"DataTime",body:self))
									result.append(vo.onFieldBegin(.flat,index:7,length:7,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:7,length:7,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:7,length:7,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostIotRestoreRequest",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetIotRestoreRequest : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/restorerequest"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/restorerequest"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostIotUnlock : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    							open var cmdTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/unlock"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/unlock"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
																					let cmdTime_ = self.cmdTime;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostIotUnlock",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"cmdTime",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:cmdTime_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"cmdTime",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostIotUnlock",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetIotUnlock : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/unlock"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/unlock"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostQueryIotDevices : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serviceId:String?
    							open var keyword:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var range:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/querydevices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/querydevices"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let keyword_ = secureKeys?["AES"]?.encrypt(original: self.keyword) ?? ""
																					let coordinate_ = secureKeys?["AES"]?.encrypt(original: self.coordinate) ?? ""
																					let coordType_ = secureKeys?["AES"]?.encrypt(original: self.coordType) ?? ""
																					let range_ = secureKeys?["AES"]?.encrypt(original: self.range) ?? ""
																					let type_ = self.type;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("appId=" + (appId_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&keyword=" + (keyword_ ?? ""))
																					md5.append("&coordinate=" + (coordinate_ ?? ""))
																					md5.append("&coordType=" + (coordType_ ?? ""))
																					md5.append("&range=" + (range_ ?? ""))
																					md5.append("&type=" + (type_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostQueryIotDevices",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"keyword",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:keyword_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"keyword",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"coordinate",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:coordinate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"coordinate",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"coordType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:coordType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"coordType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"range",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:range_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"range",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"type",body:self))
									result.append(vo.onFieldBegin(.flat,index:8,length:8,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:8,length:8,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:8,length:8,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostQueryIotDevices",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetQueryIotDevices : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [IotcaRetQueryDevicesDetail]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/querydevices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/querydevices"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("datacount"))
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetQueryDevicesDetail (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:RetQueryDevicesDetail) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetQueryDevicesDetail]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class IotcaRetQueryDevicesDetail : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    							open var deviceName:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var address:String?
    							open var status:String?
    							open var updatetime:String?
    							open var rentcount:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/querydevices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/querydevices"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		deviceId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("deviceId"))
																											cityCode = visitableSource.getValue("cityCode")
																											deviceName = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("deviceName"))
																											coordinate = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coordinate"))
																											coordType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coordType"))
																											address = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("address"))
																											status = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("status"))
																											updatetime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("updatetime"))
																											rentcount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("rentcount"))
																											type = visitableSource.getValue("type")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class IotcaPostQuerySupDevices : BaseITWebAPIBody {
	
	//
						open var coordinate:String?
    							open var coordType:String?
    							open var range:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/querySupDevices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/querySupDevices"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let coordinate_ = secureKeys?["AES"]?.encrypt(original: self.coordinate) ?? ""
																					let coordType_ = secureKeys?["AES"]?.encrypt(original: self.coordType) ?? ""
																					let range_ = secureKeys?["AES"]?.encrypt(original: self.range) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("coordinate=" + (coordinate_ ?? ""))
																					md5.append("&coordType=" + (coordType_ ?? ""))
																					md5.append("&range=" + (range_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostQuerySupDevices",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"coordinate",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:coordinate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"coordinate",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"coordType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:coordType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"coordType",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"range",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:range_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"range",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostQuerySupDevices",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetQuerySupDevices : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [IotcaRetQueryDevicesDetail]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/querySupDevices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/querySupDevices"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("datacount"))
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetQueryDevicesDetail (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:RetQueryDevicesDetail) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetQueryDevicesDetail]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class IotcaRetQueryDevicesDetail : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    							open var deviceName:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var address:String?
    							open var status:String?
    							open var updatetime:String?
    							open var maxVolume:String?
    							open var curVolume:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/querySupDevices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/querySupDevices"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		deviceId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("deviceId"))
																											cityCode = visitableSource.getValue("cityCode")
																											deviceName = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("deviceName"))
																											coordinate = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coordinate"))
																											coordType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coordType"))
																											address = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("address"))
																											status = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("status"))
																											updatetime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("updatetime"))
																											maxVolume = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("maxVolume"))
																											curVolume = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("curVolume"))
																											type = visitableSource.getValue("type")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class IotcaPostErrorRestore : BaseITWebAPIBody {
	
	//
						open var coordinate:String?
    							open var coordType:String?
    							open var deviceId:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/supErrorRestore"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/supErrorRestore"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let coordinate_ = secureKeys?["AES"]?.encrypt(original: self.coordinate) ?? ""
																					let coordType_ = secureKeys?["AES"]?.encrypt(original: self.coordType) ?? ""
																					let deviceId_ = secureKeys?["AES"]?.encrypt(original: self.deviceId) ?? ""
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("coordinate=" + (coordinate_ ?? ""))
																					md5.append("&coordType=" + (coordType_ ?? ""))
																					md5.append("&deviceId=" + (deviceId_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostErrorRestore",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"coordinate",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:coordinate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"coordinate",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"coordType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:coordType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"coordType",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"cityCode",body:self))
									result.append(vo.onFieldBegin(.flat,index:5,length:5,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:5,length:5,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:5,length:5,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostErrorRestore",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetErrorRestore : BaseITWebAPIBody {
	
	//
												open var result:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/supErrorRestore"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/supErrorRestore"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											result = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("result"))
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostBhtSwitch : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/bhtSwitch"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/bhtSwitch"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
																					let type_ = self.type;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("deviceId=" + (deviceId_ ?? ""))
																												md5.append("&type=" + (type_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostBhtSwitch",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"type",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostBhtSwitch",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetBhtSwitch : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/bhtSwitch"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/bhtSwitch"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostLockHeartBeat : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/lockHeartBeat"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/lockHeartBeat"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("deviceId=" + (deviceId_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostLockHeartBeat",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"cityCode",body:self))
									result.append(vo.onFieldBegin(.flat,index:3,length:3,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:3,length:3,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:3,length:3,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostLockHeartBeat",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetLockHeartBeat : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [IotcaRetLockHeartBeatDetail]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/lockHeartBeat"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/lockHeartBeat"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetLockHeartBeatDetail (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:RetLockHeartBeatDetail) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetLockHeartBeatDetail]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class IotcaRetLockHeartBeatDetail : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var deviceType:String?
    							open var lon:String?
    							open var lat:String?
    							open var battery:String?
    							open var versionNum:String?
    							open var lockStatus:String?
    							open var updateTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/lockHeartBeat"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/lockHeartBeat"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		deviceId = visitableSource.getValue("deviceId")
																											deviceType = visitableSource.getValue("deviceType")
																											lon = visitableSource.getValue("lon")
																											lat = visitableSource.getValue("lat")
																											battery = visitableSource.getValue("battery")
																											versionNum = visitableSource.getValue("versionNum")
																											lockStatus = visitableSource.getValue("lockStatus")
																											updateTime = visitableSource.getValue("updateTime")
															}

	//-------> list
			    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class IotcaPostSetDeviceId : BaseITWebAPIBody {
	
	//
						open var oldDeviceId:String?
    							open var newDeviceId:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/setDeviceId"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/setDeviceId"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let oldDeviceId_ = self.oldDeviceId;
																					let newDeviceId_ = self.newDeviceId;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostSetDeviceId",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"oldDeviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:oldDeviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"oldDeviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"newDeviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:newDeviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"newDeviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostSetDeviceId",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetSetDeviceId : BaseITWebAPIBody {
	
	//
												open var result:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/setDeviceId"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/setDeviceId"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											result = visitableSource.getValue("result")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostNotifyUpgrade : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var deviceType:String?
    							open var versionStr:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/notifyUpgrade"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/notifyUpgrade"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let deviceType_ = self.deviceType;
																					let versionStr_ = self.versionStr;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostNotifyUpgrade",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"deviceType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:deviceType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"deviceType",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"versionStr",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:versionStr_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"versionStr",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostNotifyUpgrade",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetNotifyUpgrade : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/notifyUpgrade"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/notifyUpgrade"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostSupplementTrip : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var deviceIdStr:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/supplementTrip"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/supplementTrip"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let deviceIdStr_ = self.deviceIdStr;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostSupplementTrip",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"deviceIdStr",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:deviceIdStr_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"deviceIdStr",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostSupplementTrip",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetSupplementTrip : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/supplementTrip"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/supplementTrip"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostGetLockPwd : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var devType:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/getLockPwd"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/getLockPwd"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let devType_ = self.devType;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostGetLockPwd",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"devType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:devType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"devType",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostGetLockPwd",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetGetLockPwd : BaseITWebAPIBody {
	
	//
												open var openPwd:String?
    							open var closePwd:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/getLockPwd"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/getLockPwd"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											openPwd = visitableSource.getValue("openPwd")
																											closePwd = visitableSource.getValue("closePwd")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostTimeCorrect : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/timeCorrect"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/timeCorrect"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostTimeCorrect",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"deviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostTimeCorrect",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetTimeCorrect : BaseITWebAPIBody {
	
	//
												open var result:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/timeCorrect"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/timeCorrect"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											result = visitableSource.getValue("result")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostCurrentAmount : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/currentAmount"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/currentAmount"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostCurrentAmount",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"deviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostCurrentAmount",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetCurrentAmount : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/currentAmount"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/currentAmount"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostCmdLock : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cmdType:String?
    							open var extraCmd:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/cmdLock"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/cmdLock"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let cmdType_ = self.cmdType;
																					let extraCmd_ = self.extraCmd;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostCmdLock",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"cmdType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:cmdType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"cmdType",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"extraCmd",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:extraCmd_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"extraCmd",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostCmdLock",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetCmdLock : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/cmdLock"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/cmdLock"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostLockStatusCmd : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cmdOrder:String?
    							open var orderType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/lockStatusCmd"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/lockStatusCmd"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let cmdOrder_ = self.cmdOrder;
																					let orderType_ = self.orderType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostLockStatusCmd",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"cmdOrder",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:cmdOrder_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"cmdOrder",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"orderType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:orderType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"orderType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostLockStatusCmd",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetLockStatusCmd : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/lockStatusCmd"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/lockStatusCmd"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostCurrencyPush : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var pushContent:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/currencyPush"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/currencyPush"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let pushContent_ = self.pushContent;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostCurrencyPush",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"pushContent",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:pushContent_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"pushContent",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostCurrencyPush",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetCurrencyPush : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/currencyPush"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/currencyPush"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostPushOntMsg : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var bikeCount:String?
    							open var macList:String?
    							open var time:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/pushOntMsg"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/pushOntMsg"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let bikeCount_ = self.bikeCount;
																					let macList_ = self.macList;
																					let time_ = self.time;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostPushOntMsg",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"bikeCount",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:bikeCount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"bikeCount",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"macList",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:macList_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"macList",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"time",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:time_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"time",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostPushOntMsg",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetPushOntMsg : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/pushOntMsg"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/pushOntMsg"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostOntPileHeartbeat : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var status:String?
    							open var time:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/ontPileHeartbeat"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/ontPileHeartbeat"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let status_ = self.status;
																					let time_ = self.time;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostOntPileHeartbeat",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"status",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:status_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"status",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"time",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:time_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"time",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostOntPileHeartbeat",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetOntPileHeartbeat : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/ontPileHeartbeat"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/ontPileHeartbeat"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostConfirmTheLock : BaseITWebAPIBody {
	
	//
						open var cityCode:String?
    							open var deviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/confirmTheLock"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/confirmTheLock"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let cityCode_ = self.cityCode;
																					let deviceId_ = self.deviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostConfirmTheLock",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"deviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostConfirmTheLock",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetConfirmTheLock : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/confirmTheLock"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/confirmTheLock"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostRentBikeFault : BaseITWebAPIBody {
	
	//
									open var bikeId:String?
    							open var initCheck:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/rentBikeFault"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/rentBikeFault"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let bikeId_ = self.bikeId;
																					let initCheck_ = self.initCheck;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostRentBikeFault",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"bikeId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:bikeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"bikeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"initCheck",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:initCheck_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"initCheck",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostRentBikeFault",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetRentBikeFault : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/rentBikeFault"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/rentBikeFault"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostReturnBikeReq : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    							open var deviceType:String?
    							open var lon:String?
    							open var lat:String?
    							open var checkMessId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/returnBikeReq"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/returnBikeReq"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
																					let deviceType_ = self.deviceType;
																					let lon_ = self.lon;
																					let lat_ = self.lat;
																					let checkMessId_ = self.checkMessId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostReturnBikeReq",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:7,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:7,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:7,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:7,field:"deviceType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:7,value:deviceType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:7,field:"deviceType",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:7,field:"lon",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:7,value:lon_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:7,field:"lon",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:7,field:"lat",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:7,value:lat_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:7,field:"lat",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:7,field:"checkMessId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:7,value:checkMessId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:7,field:"checkMessId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostReturnBikeReq",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetReturnBikeReq : BaseITWebAPIBody {
	
	//
												open var whetherInEnclosure:String?
    							open var enclosureName:String?
    							open var electricFenceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/returnBikeReq"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/returnBikeReq"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											whetherInEnclosure = visitableSource.getValue("whetherInEnclosure")
																											enclosureName = visitableSource.getValue("enclosureName")
																											electricFenceId = visitableSource.getValue("electricFenceId")
															}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostSendOutMqReq : BaseITWebAPIBody {
	
	//
						open var tag:String?
    							open var message:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/sendOutMqReq"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/sendOutMqReq"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let tag_ = self.tag;
																					let message_ = self.message;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostSendOutMqReq",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"tag",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:tag_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"tag",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"message",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:message_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"message",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostSendOutMqReq",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetSendOutMqReq : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/sendOutMqReq"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/sendOutMqReq"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostUpgradNnotify : BaseITWebAPIBody {
	
	//
						open var md5Str:String?
    							open var updateVersion:String?
    							open var firmwareType:String?
    							open var deviceIds:String?
    							open var devType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/upgradNnotify"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/upgradNnotify"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let md5Str_ = self.md5Str;
																					let updateVersion_ = self.updateVersion;
																					let firmwareType_ = self.firmwareType;
																					let deviceIds_ = self.deviceIds;
																					let devType_ = self.devType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostUpgradNnotify",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"md5Str",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:md5Str_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"md5Str",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"updateVersion",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:updateVersion_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"updateVersion",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"firmwareType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:firmwareType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"firmwareType",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"deviceIds",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:deviceIds_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"deviceIds",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"devType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:devType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"devType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostUpgradNnotify",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetUpgradNnotify : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/upgradNnotify"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/upgradNnotify"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostAudioUpgrade : BaseITWebAPIBody {
	
	//
						open var fileType:String?
    							open var fileName:String?
    							open var deviceIds:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/audioUpgrade"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/audioUpgrade"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let fileType_ = self.fileType;
																					let fileName_ = self.fileName;
																					let deviceIds_ = self.deviceIds;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostAudioUpgrade",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"fileType",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:fileType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"fileType",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"fileName",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:fileName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"fileName",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"deviceIds",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:deviceIds_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"deviceIds",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostAudioUpgrade",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetAudioUpgrade : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/audioUpgrade"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/audioUpgrade"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostForwardConfig : BaseITWebAPIBody {
	
	//
						open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/iotForwardConfig"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/iotForwardConfig"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostForwardConfig",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostForwardConfig",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetForwardConfig : BaseITWebAPIBody {
	
	//
						open var cityCode:String?
    							open var tag:String?
    								
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/iotForwardConfig"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/iotForwardConfig"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		cityCode = visitableSource.getValue("cityCode")
																											tag = visitableSource.getValue("tag")
																											retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostRepayBikeLocReq : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    							open var lockStatus:String?
    							open var whetherSucceed:String?
    							open var longitudeCoordinate:String?
    							open var latitudeCoordinates:String?
    							open var operId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/repayBikeLocReq"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/repayBikeLocReq"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
																					let lockStatus_ = self.lockStatus;
																					let whetherSucceed_ = self.whetherSucceed;
																					let longitudeCoordinate_ = self.longitudeCoordinate;
																					let latitudeCoordinates_ = self.latitudeCoordinates;
																					let operId_ = self.operId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostRepayBikeLocReq",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"lockStatus",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:lockStatus_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"lockStatus",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"whetherSucceed",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:whetherSucceed_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"whetherSucceed",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"longitudeCoordinate",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:longitudeCoordinate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"longitudeCoordinate",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"latitudeCoordinates",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:latitudeCoordinates_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"latitudeCoordinates",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"operId",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:operId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"operId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostRepayBikeLocReq",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetRepayBikeLocReq : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/repayBikeLocReq"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/repayBikeLocReq"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostCp4ConfigDown : BaseITWebAPIBody {
	
	//
						open var deviceIds:String?
    							open var scanCount:String?
    							open var isUnlock:String?
    							open var rssi:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/cp4ConfigDown"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/cp4ConfigDown"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceIds_ = self.deviceIds;
																					let scanCount_ = self.scanCount;
																					let isUnlock_ = self.isUnlock;
																					let rssi_ = self.rssi;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostCp4ConfigDown",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"deviceIds",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:deviceIds_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"deviceIds",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"scanCount",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:scanCount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"scanCount",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"isUnlock",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:isUnlock_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"isUnlock",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"rssi",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:rssi_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"rssi",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostCp4ConfigDown",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class IotcaRetCp4ConfigDown : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/cp4ConfigDown"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/cp4ConfigDown"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class IotcaPostFaultReturnBike : BaseITWebAPIBody {
	
	//
									open var lat:String?
    							open var lng:String?
    							open var coordinateType:String?
    							open var tripId:String?
    				    		//----->list
			fileprivate var nailPileList = [IotcaBleScanNail]()
			//>-----
					    		//----->list
			fileprivate var siteList = [IotcaBleScanSite]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/faultreturnbike"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/faultreturnbike"
        	}

	//-------> list
			    		    		    		    		    			    open func addNailPileList(subBody:BleScanNail) -> Void{
	        data.append(subBody)
	    }

	    open func getNailPileList() -> [BleScanNail]{
	        return data
	    }
	        			    open func addSiteList(subBody:BleScanSite) -> Void{
	        data.append(subBody)
	    }

	    open func getSiteList() -> [BleScanSite]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let lat_ = self.lat;
																					let lng_ = self.lng;
																					let coordinateType_ = self.coordinateType;
																					let tripId_ = self.tripId;
																									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"IotcaPostFaultReturnBike",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"lat",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:lat_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"lat",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"lng",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:lng_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"lng",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"coordinateType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:coordinateType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"coordinateType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"tripId",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:tripId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"tripId",body:self))
												//----->list
				result.append(vo.onFieldBegin(.array,index:6,length:8,field:"nailPileList",body:self))
				var nailPileList_index_ = 1;
				var nailPileList_length_ = nailPileList .count
				for object in self.nailPileList {
					result.append(object.encode(nailPileList_index_,lenght:nailPileList_length_,visitableObject:visitableObject,secureKeys:secureKeys)) ?? "")
					nailPileList_index_ ++;
				}
				result.append(vo.onFieldEnd(.array,index:6,length:8,field:"nailPileList",body:self))
				//>-----
												//----->list
				result.append(vo.onFieldBegin(.array,index:7,length:8,field:"siteList",body:self))
				var siteList_index_ = 1;
				var siteList_length_ = siteList .count
				for object in self.siteList {
					result.append(object.encode(siteList_index_,lenght:siteList_length_,visitableObject:visitableObject,secureKeys:secureKeys)) ?? "")
					siteList_index_ ++;
				}
				result.append(vo.onFieldEnd(.array,index:7,length:8,field:"siteList",body:self))
				//>-----
									result.append(vo.onObjectEnd(index,length:length,objname:"IotcaPostFaultReturnBike",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    																																		
open class IotcaBleScanNail : BaseITWebAPIBody {
	
	//
						open var deviceName:String?
    							open var MAC:String?
    							open var RSSI:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/faultreturnbike"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/faultreturnbike"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		deviceName = visitableSource.getValue("deviceName")
																											MAC = visitableSource.getValue("MAC")
																											RSSI = visitableSource.getValue("RSSI")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
												
open class IotcaBleScanSite : BaseITWebAPIBody {
	
	//
						open var deviceName:String?
    							open var MAC:String?
    							open var RSSI:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/faultreturnbike"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/faultreturnbike"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		deviceName = visitableSource.getValue("deviceName")
																											MAC = visitableSource.getValue("MAC")
																											RSSI = visitableSource.getValue("RSSI")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class IotcaRetFaultReturnBike : BaseITWebAPIBody {
	
	//
												open var checkStatus:String?
    							open var siteId:String?
    							open var siteName:String?
    							open var lngLat:String?
    		
	required public init(){
		super.init()
		self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/faultreturnbike"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "44"
		self.appName_ = "iotca"
		self.mapping_ = "/api/iotca/business/faultreturnbike"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											checkStatus = visitableSource.getValue("checkStatus")
																											siteId = visitableSource.getValue("siteId")
																											siteName = visitableSource.getValue("siteName")
																											lngLat = visitableSource.getValue("lngLat")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
