import Foundation
import ITWebAPI
// MARK: Factory
open class BikecaWebAPIContext : ITWebAPIContext{
	required public init(){}
    open var visitablePair:ITVisitablePair = ITXmlVisitablePair()
    open var secureKeys = [String:ITSecureKey]()
    open func setSecureKey(_ secureKey:ITSecureKey?) -> ITWebAPIContext?{
        if let secureKey_ = secureKey {
            secureKeys[secureKey_.name] = secureKey_
        }
        return self
    }

    open func getSecureKey(_ keyName:String) -> ITSecureKey? {
        return self.secureKeys[keyName]
    }

    open func getSecureKeys() -> [String:ITSecureKey]? {
        return self.secureKeys
    }

    open func createRequestBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody{
        if secureKey == nil {
            return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open func createResponseBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody {
        if secureKey == nil {
            return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open enum BodyType{
        case requestBody
        case responseBody
    }

    open func createBody(type:BodyType,requestMapping:String,content:String?,secureKeys:[String:ITSecureKey]) -> ITWebAPIBody{
        var body:ITWebAPIBody
        switch(requestMapping){
        				case "/api/bikeca/business/bizinfo":
				if type == .requestBody {
                    body = BikecaPostBizinfo()
                } else {
                    body = BikecaRetBizinfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/serviceInfo":
				if type == .requestBody {
                    body = BikecaPostServiceinfo()
                } else {
                    body = BikecaRetServiceinfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/querydevices":
				if type == .requestBody {
                    body = BikecaPostQueryDevices()
                } else {
                    body = BikecaRetQueryDevices(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/getdevicestatus":
				if type == .requestBody {
                    body = BikecaPostGetDeviceStatus()
                } else {
                    body = BikecaRetGetDeviceStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/enabletrade":
				if type == .requestBody {
                    body = BikecaPostEnableTrade()
                } else {
                    body = BikecaRetEnableTrade(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/disabletrade":
				if type == .requestBody {
                    body = BikecaPostDisableTrade()
                } else {
                    body = BikecaRetDisableTrade(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/request":
				if type == .requestBody {
                    body = BikecaPostRequest()
                } else {
                    body = BikecaRetRequest(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/hireinfo":
				if type == .requestBody {
                    body = BikecaPostHireinfo()
                } else {
                    body = BikecaRetHireinfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/restoreinfo":
				if type == .requestBody {
                    body = BikecaPostRestoreinfo()
                } else {
                    body = BikecaRetRestoreinfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/errorhdlinfo":
				if type == .requestBody {
                    body = BikecaPostErrorhdlinfo()
                } else {
                    body = BikecaRetErrorhdlinfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/pertrips":
				if type == .requestBody {
                    body = BikecaPostPerTripRecords()
                } else {
                    body = BikecaRetPerTripRecords(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/pertripsNew":
				if type == .requestBody {
                    body = BikecaPostPerTripRecordsNew()
                } else {
                    body = BikecaRetPerTripRecordsNew(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/checkOrderStatus":
				if type == .requestBody {
                    body = BikecaPostCheckOrderStatus()
                } else {
                    body = BikecaRetCheckOrderStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/checkCertifyStatus":
				if type == .requestBody {
                    body = BikecaPostCheckCertifyStatus()
                } else {
                    body = BikecaRetCheckCertifyStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/checkTodayCyc":
				if type == .requestBody {
                    body = BikecaPostCheckTodayCyc()
                } else {
                    body = BikecaRetCheckTodayCyc(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/reletPriceList":
				if type == .requestBody {
                    body = BikecaPostReletPriceList()
                } else {
                    body = BikecaRetReletPriceList(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/insertReletRecord":
				if type == .requestBody {
                    body = BikecaPostInsertReletRecord()
                } else {
                    body = BikecaRetInsertReletRecord(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/deleteReletRecord":
				if type == .requestBody {
                    body = BikecaPostDeleteReletRecord()
                } else {
                    body = BikecaRetDeleteReletRecord(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/getPriceList":
				if type == .requestBody {
                    body = BikecaPostGetPriceList()
                } else {
                    body = BikecaRetGetPriceList(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/getCouponUser":
				if type == .requestBody {
                    body = BikecaPostGetCouponUser()
                } else {
                    body = BikecaRetGetCouponUser(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/getUserInfo":
				if type == .requestBody {
                    body = BikecaPostGetUserInfo()
                } else {
                    body = BikecaRetGetUserInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/tripOverView":
				if type == .requestBody {
                    body = BikecaPostTripOverView()
                } else {
                    body = BikecaRetTripOverView(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/queryProgress":
				if type == .requestBody {
                    body = BikecaPostQueryProgress()
                } else {
                    body = BikecaRetQueryProgress(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/revokeRefund":
				if type == .requestBody {
                    body = BikecaPostRevokeRefund()
                } else {
                    body = BikecaRetRevokeRefund(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/changeRefund":
				if type == .requestBody {
                    body = BikecaPostChangeRefund()
                } else {
                    body = BikecaRetChangeRefund(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/inner/updateBizStatusByService":
				if type == .requestBody {
                    body = BikecaPostUpdateBizStatus()
                } else {
                    body = BikecaRetUpdateBizStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/inner/updateIbikeUserStatus":
				if type == .requestBody {
                    body = BikecaPostUpdateIbikeUserStatus()
                } else {
                    body = BikecaRetUpdateIbikeUserStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/extra/getInvitationInfo":
				if type == .requestBody {
                    body = BikecaPostGetInvitationInfo()
                } else {
                    body = BikecaRetGetInvitationInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/extra/inviteExpr":
				if type == .requestBody {
                    body = BikecaPostInviteExpr()
                } else {
                    body = BikecaRetInviteExpr(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/extra/intimateBind":
				if type == .requestBody {
                    body = BikecaPostIntimateBind()
                } else {
                    body = BikecaRetIntimateBind(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/card/userBuyCard":
				if type == .requestBody {
                    body = BikecaPostUserBuyCard()
                } else {
                    body = BikecaRetUserBuyCard(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/card/queryCardDaysRemaining":
				if type == .requestBody {
                    body = BikecaPostQueryCardDaysRemainingd()
                } else {
                    body = BikecaRetQueryCardDaysRemaining(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/card/queryUserCard":
				if type == .requestBody {
                    body = BikecaPostQueryUserCard()
                } else {
                    body = BikecaRetQueryUserCard(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/card/queryCardAndDaysRemaining":
				if type == .requestBody {
                    body = BikecaPostQueryCardAndDaysRemainingd()
                } else {
                    body = BikecaRetQueryCardAndDaysRemaining(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/card/getCardDetailList":
				if type == .requestBody {
                    body = BikecaPostGetCardDetailList()
                } else {
                    body = BikecaRetGetCardDetailList(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/card/getUserBuyCardList":
				if type == .requestBody {
                    body = BikecaPostGetUserBuyCardList()
                } else {
                    body = BikecaRetGetUserBuyCardList(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/checkBuyOrderStatus":
				if type == .requestBody {
                    body = BikecaPostCheckBuyOrderStatus()
                } else {
                    body = BikecaRetCheckBuyOrderStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/config/getCommonConfigList":
				if type == .requestBody {
                    body = BikecaPostGetCommonConfigList()
                } else {
                    body = BikecaRetGetCommonConfigList(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/checkCloudPosOrderStatus":
				if type == .requestBody {
                    body = BikecaPostCheckCloudPosOrderStatus()
                } else {
                    body = BikecaRetCheckCloudPosOrderStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/useWalletForBusiness":
				if type == .requestBody {
                    body = BikecaPostUseWalletForBusiness()
                } else {
                    body = BikecaRetUseWalletForBusiness(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/card/freeCardActivity":
				if type == .requestBody {
                    body = BikecaPostFreeCardActivity()
                } else {
                    body = BikecaRetFreeCardActivity(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/openBizAgree":
				if type == .requestBody {
                    body = BikecaPostOpenBizAgree()
                } else {
                    body = BikecaRetOpenBizAgree(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/getBizAgree":
				if type == .requestBody {
                    body = BikecaPostGetBizAgree()
                } else {
                    body = BikecaRetGetBizAgree(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/getTripInfo":
				if type == .requestBody {
                    body = BikecaPostGetTripInfo()
                } else {
                    body = BikecaRetGetTripInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/external/callback":
				if type == .requestBody {
                    body = BikecaPostCall()
                } else {
                    body = BikecaRetCall(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/calculationFee":
				if type == .requestBody {
                    body = BikecaPostCalculationFee()
                } else {
                    body = BikecaRetCalculationFee(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/changeUserStatus":
				if type == .requestBody {
                    body = BikecaPostChangeUserStatus()
                } else {
                    body = BikecaRetChangeUserStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/purchase/yearCardInvalid":
				if type == .requestBody {
                    body = BikecaPostYearCardInvalid()
                } else {
                    body = BikecaRetYearCardInvalid(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/purchase/yearCardPlaceAnOrder":
				if type == .requestBody {
                    body = BikecaPostYearCardPlaceAnOrder()
                } else {
                    body = BikecaRetYearCardPlaceAnOrder(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/overNight":
				if type == .requestBody {
                    body = BikecaPostOverNight()
                } else {
                    body = BikecaRetOverNight(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikeca/business/suppl":
				if type == .requestBody {
                    body = BikecaPostSuppl()
                } else {
                    body = BikecaRetSuppl(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						default:
			body = BaseITWebAPIBody()
        }
        body.context = self
        return body
    }
}


		
open class BikecaPostBizinfo : BaseITWebAPIBody {
	
	//
									open var appId:String?
    							open var serviceId:String?
    							open var bizType:String?
    							open var terminalType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/bizinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/bizinfo"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let bizType_ = self.bizType;
																					let terminalType_ = self.terminalType;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																												
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostBizinfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"bizType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:bizType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"bizType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"terminalType",body:self))
									result.append(vo.onFieldBegin(.flat,index:6,length:6,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:6,length:6,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:6,length:6,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostBizinfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetBizinfo : BaseITWebAPIBody {
	
	//
												open var sysTime:String?
    							open var userId:String?
    							open var phoneNum:String?
    							open var bizStatus:String?
    							open var bizExtra:String?
    							open var bizMoney:String?
    							open var certStatus:String?
    							open var openTime:String?
    							open var closeTime:String?
    							open var operId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/bizinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/bizinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											sysTime = visitableSource.getValue("sysTime")
																											userId = visitableSource.getValue("userId")
																											phoneNum = visitableSource.getValue("phoneNum")
																											bizStatus = visitableSource.getValue("bizStatus")
																											bizExtra = visitableSource.getValue("bizExtra")
																											bizMoney = visitableSource.getValue("bizMoney")
																											certStatus = visitableSource.getValue("certStatus")
																											openTime = visitableSource.getValue("openTime")
																											closeTime = visitableSource.getValue("closeTime")
																											operId = visitableSource.getValue("operId")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostServiceinfo : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serviceId:String?
    							open var bizType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/serviceInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/serviceInfo"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let bizType_ = self.bizType;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("appId=" + (appId_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostServiceinfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"bizType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:bizType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"bizType",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostServiceinfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetServiceinfo : BaseITWebAPIBody {
	
	//
												open var serviceId:String?
    							open var serviceName:String?
    							open var openMoney:String?
    							open var serviceExtra:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/serviceInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/serviceInfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											serviceId = visitableSource.getValue("serviceId")
																											serviceName = visitableSource.getValue("serviceName")
																											openMoney = visitableSource.getValue("openMoney")
																											serviceExtra = visitableSource.getValue("serviceExtra")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostQueryDevices : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serviceId:String?
    							open var keyword:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var range:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/querydevices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/querydevices"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let keyword_ = secureKeys?["AES"]?.encrypt(original: self.keyword) ?? ""
																					let coordinate_ = secureKeys?["AES"]?.encrypt(original: self.coordinate) ?? ""
																					let coordType_ = secureKeys?["AES"]?.encrypt(original: self.coordType) ?? ""
																					let range_ = secureKeys?["AES"]?.encrypt(original: self.range) ?? ""
																					let type_ = self.type;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("appId=" + (appId_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&keyword=" + (keyword_ ?? ""))
																					md5.append("&coordinate=" + (coordinate_ ?? ""))
																					md5.append("&coordType=" + (coordType_ ?? ""))
																					md5.append("&range=" + (range_ ?? ""))
																					md5.append("&type=" + (type_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostQueryDevices",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"keyword",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:keyword_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"keyword",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"coordinate",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:coordinate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"coordinate",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"coordType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:coordType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"coordType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"range",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:range_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"range",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"type",body:self))
									result.append(vo.onFieldBegin(.flat,index:8,length:8,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:8,length:8,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:8,length:8,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostQueryDevices",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetQueryDevices : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikecaRetQueryDevicesDetail]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/querydevices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/querydevices"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("datacount"))
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetQueryDevicesDetail (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:RetQueryDevicesDetail) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetQueryDevicesDetail]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikecaRetQueryDevicesDetail : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var deviceName:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var address:String?
    							open var status:String?
    							open var updatetime:String?
    							open var totalcount:String?
    							open var rentcount:String?
    							open var restorecount:String?
    							open var type:String?
    							open var redpacPileFlag:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/querydevices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/querydevices"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		deviceId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("deviceId"))
																											deviceName = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("deviceName"))
																											coordinate = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coordinate"))
																											coordType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coordType"))
																											address = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("address"))
																											status = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("status"))
																											updatetime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("updatetime"))
																											totalcount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("totalcount"))
																											rentcount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("rentcount"))
																											restorecount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("restorecount"))
																											type = visitableSource.getValue("type")
																											redpacPileFlag = visitableSource.getValue("redpacPileFlag")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikecaPostGetDeviceStatus : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serviceId:String?
    							open var deviceId:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getdevicestatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getdevicestatus"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let deviceId_ = secureKeys?["AES"]?.encrypt(original: self.deviceId) ?? ""
																					let type_ = secureKeys?["AES"]?.encrypt(original: self.type) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("appId=" + (appId_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&deviceId=" + (deviceId_ ?? ""))
																					md5.append("&type=" + (type_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostGetDeviceStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"type",body:self))
									result.append(vo.onFieldBegin(.flat,index:5,length:5,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:5,length:5,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:5,length:5,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostGetDeviceStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetGetDeviceStatus : BaseITWebAPIBody {
	
	//
												open var deviceId:String?
    							open var deviceName:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var address:String?
    							open var status:String?
    							open var updatetime:String?
    							open var totalcount:String?
    							open var rentcount:String?
    							open var restorecount:String?
    							open var posinfos:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getdevicestatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getdevicestatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											deviceId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("deviceId"))
																											deviceName = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("deviceName"))
																											coordinate = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coordinate"))
																											coordType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coordType"))
																											address = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("address"))
																											status = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("status"))
																											updatetime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("updatetime"))
																											totalcount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("totalcount"))
																											rentcount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("rentcount"))
																											restorecount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("restorecount"))
																											posinfos = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("posinfos"))
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostEnableTrade : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var bizType:String?
    							open var bizLevel:String?
    							open var certMode:String?
    							open var certParams:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/enabletrade"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/enabletrade"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let bizType_ = secureKeys?["AES"]?.encrypt(original: self.bizType) ?? ""
																					let bizLevel_ = secureKeys?["AES"]?.encrypt(original: self.bizLevel) ?? ""
																					let certMode_ = self.certMode;
																					let certParams_ = self.certParams;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&bizType=" + (bizType_ ?? ""))
																					md5.append("&bizLevel=" + (bizLevel_ ?? ""))
																												
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostEnableTrade",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"bizType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:bizType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"bizType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"bizLevel",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:bizLevel_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"bizLevel",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"certMode",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:certMode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"certMode",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"certParams",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:certParams_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"certParams",body:self))
									result.append(vo.onFieldBegin(.flat,index:8,length:8,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:8,length:8,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:8,length:8,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostEnableTrade",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetEnableTrade : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    							open var orderId:String?
    							open var orderNo:String?
    							open var certStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/enabletrade"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/enabletrade"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("bizStatus"))
																											orderId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderId"))
																											orderNo = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderNo"))
																											certStatus = visitableSource.getValue("certStatus")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostDisableTrade : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var bizType:String?
    							open var refReason:String?
    							open var terminalType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/disabletrade"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/disabletrade"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let bizType_ = secureKeys?["AES"]?.encrypt(original: self.bizType) ?? ""
																					let refReason_ = self.refReason;
																					let terminalType_ = self.terminalType;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&bizType=" + (bizType_ ?? ""))
																												
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostDisableTrade",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:7,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:7,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:7,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:7,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:7,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:7,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:7,field:"bizType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:7,value:bizType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:7,field:"bizType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:7,field:"refReason",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:7,value:refReason_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:7,field:"refReason",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:7,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:7,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:7,field:"terminalType",body:self))
									result.append(vo.onFieldBegin(.flat,index:7,length:7,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:7,length:7,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:7,length:7,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostDisableTrade",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetDisableTrade : BaseITWebAPIBody {
	
	//
						open var refund:String?
    													open var bizStatus:String?
    							open var closeTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/disabletrade"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/disabletrade"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		refund = visitableSource.getValue("refund")
																											retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("bizStatus"))
																											closeTime = visitableSource.getValue("closeTime")
															}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostRequest : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var terminalType:String?
    							open var requestType:String?
    							open var DeviceId:String?
    							open var parkNum:String?
    							open var cityCode:String?
    							open var bizType:String?
    							open var alipayId:String?
    							open var bikeId:String?
    							open var phoneLocation:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/request"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/request"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let terminalType_ = secureKeys?["AES"]?.encrypt(original: self.terminalType) ?? ""
																					let requestType_ = secureKeys?["AES"]?.encrypt(original: self.requestType) ?? ""
																					let DeviceId_ = secureKeys?["AES"]?.encrypt(original: self.DeviceId) ?? ""
																					let parkNum_ = secureKeys?["AES"]?.encrypt(original: self.parkNum) ?? ""
																					let cityCode_ = self.cityCode;
																					let bizType_ = self.bizType;
																					let alipayId_ = self.alipayId;
																					let bikeId_ = self.bikeId;
																					let phoneLocation_ = self.phoneLocation;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&terminalType=" + (terminalType_ ?? ""))
																					md5.append("&requestType=" + (requestType_ ?? ""))
																					md5.append("&DeviceId=" + (DeviceId_ ?? ""))
																					md5.append("&parkNum=" + (parkNum_ ?? ""))
																																																	
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostRequest",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:13,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:13,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:13,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:13,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:13,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:13,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:13,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:13,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:13,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:13,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:13,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:13,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:13,field:"requestType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:13,value:requestType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:13,field:"requestType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:13,field:"DeviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:13,value:DeviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:13,field:"DeviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:13,field:"parkNum",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:13,value:parkNum_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:13,field:"parkNum",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:13,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:13,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:13,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:13,field:"bizType",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:13,value:bizType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:13,field:"bizType",body:self))
												result.append(vo.onFieldBegin(.flat,index:10,length:13,field:"alipayId",body:self))
				result.append(vo.onFieldValue(.flat,index:10,length:13,value:alipayId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:10,length:13,field:"alipayId",body:self))
												result.append(vo.onFieldBegin(.flat,index:11,length:13,field:"bikeId",body:self))
				result.append(vo.onFieldValue(.flat,index:11,length:13,value:bikeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:11,length:13,field:"bikeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:12,length:13,field:"phoneLocation",body:self))
				result.append(vo.onFieldValue(.flat,index:12,length:13,value:phoneLocation_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:12,length:13,field:"phoneLocation",body:self))
									result.append(vo.onFieldBegin(.flat,index:13,length:13,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:13,length:13,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:13,length:13,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostRequest",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetRequest : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    							open var reqStatus:String?
    							open var serviceId:String?
    							open var orderId:String?
    							open var operId:String?
    							open var reqExtra:String?
    							open var iotStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/request"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/request"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
																											reqStatus = visitableSource.getValue("reqStatus")
																											serviceId = visitableSource.getValue("serviceId")
																											orderId = visitableSource.getValue("orderId")
																											operId = visitableSource.getValue("operId")
																											reqExtra = visitableSource.getValue("reqExtra")
																											iotStatus = visitableSource.getValue("iotStatus")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostHireinfo : BaseITWebAPIBody {
	
	//
						open var userId:String?
    							open var userPhone:String?
    							open var cityCode:String?
    							open var bikeId:String?
    							open var loginType:String?
    							open var hireDeviceId:String?
    							open var hireDeviceName:String?
    							open var hireParkNum:String?
    							open var hireDate:String?
    							open var operId:String?
    							open var cityName:String?
    							open var sitePositionType:String?
    							open var hireSitePosition:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/hireinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/hireinfo"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let userId_ = secureKeys?["AES"]?.encrypt(original: self.userId) ?? ""
																					let userPhone_ = secureKeys?["AES"]?.encrypt(original: self.userPhone) ?? ""
																					let cityCode_ = secureKeys?["AES"]?.encrypt(original: self.cityCode) ?? ""
																					let bikeId_ = secureKeys?["AES"]?.encrypt(original: self.bikeId) ?? ""
																					let loginType_ = secureKeys?["AES"]?.encrypt(original: self.loginType) ?? ""
																					let hireDeviceId_ = secureKeys?["AES"]?.encrypt(original: self.hireDeviceId) ?? ""
																					let hireDeviceName_ = secureKeys?["AES"]?.encrypt(original: self.hireDeviceName) ?? ""
																					let hireParkNum_ = secureKeys?["AES"]?.encrypt(original: self.hireParkNum) ?? ""
																					let hireDate_ = secureKeys?["AES"]?.encrypt(original: self.hireDate) ?? ""
																					let operId_ = secureKeys?["AES"]?.encrypt(original: self.operId) ?? ""
																					let cityName_ = secureKeys?["AES"]?.encrypt(original: self.cityName) ?? ""
																					let sitePositionType_ = self.sitePositionType;
																					let hireSitePosition_ = self.hireSitePosition;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("userId=" + (userId_ ?? ""))
																					md5.append("&userPhone=" + (userPhone_ ?? ""))
																					md5.append("&cityCode=" + (cityCode_ ?? ""))
																					md5.append("&bikeId=" + (bikeId_ ?? ""))
																					md5.append("&loginType=" + (loginType_ ?? ""))
																					md5.append("&hireDeviceId=" + (hireDeviceId_ ?? ""))
																					md5.append("&hireDeviceName=" + (hireDeviceName_ ?? ""))
																					md5.append("&hireParkNum=" + (hireParkNum_ ?? ""))
																					md5.append("&hireDate=" + (hireDate_ ?? ""))
																					md5.append("&operId=" + (operId_ ?? ""))
																					md5.append("&cityName=" + (cityName_ ?? ""))
																												
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostHireinfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:14,field:"userId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:14,value:userId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:14,field:"userId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:14,field:"userPhone",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:14,value:userPhone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:14,field:"userPhone",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:14,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:14,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:14,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:14,field:"bikeId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:14,value:bikeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:14,field:"bikeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:14,field:"loginType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:14,value:loginType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:14,field:"loginType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:14,field:"hireDeviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:14,value:hireDeviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:14,field:"hireDeviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:14,field:"hireDeviceName",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:14,value:hireDeviceName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:14,field:"hireDeviceName",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:14,field:"hireParkNum",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:14,value:hireParkNum_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:14,field:"hireParkNum",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:14,field:"hireDate",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:14,value:hireDate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:14,field:"hireDate",body:self))
												result.append(vo.onFieldBegin(.flat,index:10,length:14,field:"operId",body:self))
				result.append(vo.onFieldValue(.flat,index:10,length:14,value:operId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:10,length:14,field:"operId",body:self))
												result.append(vo.onFieldBegin(.flat,index:11,length:14,field:"cityName",body:self))
				result.append(vo.onFieldValue(.flat,index:11,length:14,value:cityName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:11,length:14,field:"cityName",body:self))
												result.append(vo.onFieldBegin(.flat,index:12,length:14,field:"sitePositionType",body:self))
				result.append(vo.onFieldValue(.flat,index:12,length:14,value:sitePositionType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:12,length:14,field:"sitePositionType",body:self))
												result.append(vo.onFieldBegin(.flat,index:13,length:14,field:"hireSitePosition",body:self))
				result.append(vo.onFieldValue(.flat,index:13,length:14,value:hireSitePosition_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:13,length:14,field:"hireSitePosition",body:self))
									result.append(vo.onFieldBegin(.flat,index:14,length:14,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:14,length:14,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:14,length:14,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostHireinfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetHireinfo : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/hireinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/hireinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostRestoreinfo : BaseITWebAPIBody {
	
	//
						open var userId:String?
    							open var userPhone:String?
    							open var cityCode:String?
    							open var bikeId:String?
    							open var loginType:String?
    							open var hireDeviceId:String?
    							open var hireDeviceName:String?
    							open var hireParkNum:String?
    							open var hireDate:String?
    							open var restoreDeviceId:String?
    							open var restoreDeviceName:String?
    							open var restoreParkNum:String?
    							open var restoreDate:String?
    							open var hireFee:String?
    							open var operId:String?
    							open var cityName:String?
    							open var sitePositionType:String?
    							open var restoreSitePosition:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/restoreinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/restoreinfo"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let userId_ = secureKeys?["AES"]?.encrypt(original: self.userId) ?? ""
																					let userPhone_ = secureKeys?["AES"]?.encrypt(original: self.userPhone) ?? ""
																					let cityCode_ = secureKeys?["AES"]?.encrypt(original: self.cityCode) ?? ""
																					let bikeId_ = secureKeys?["AES"]?.encrypt(original: self.bikeId) ?? ""
																					let loginType_ = secureKeys?["AES"]?.encrypt(original: self.loginType) ?? ""
																					let hireDeviceId_ = secureKeys?["AES"]?.encrypt(original: self.hireDeviceId) ?? ""
																					let hireDeviceName_ = secureKeys?["AES"]?.encrypt(original: self.hireDeviceName) ?? ""
																					let hireParkNum_ = secureKeys?["AES"]?.encrypt(original: self.hireParkNum) ?? ""
																					let hireDate_ = secureKeys?["AES"]?.encrypt(original: self.hireDate) ?? ""
																					let restoreDeviceId_ = secureKeys?["AES"]?.encrypt(original: self.restoreDeviceId) ?? ""
																					let restoreDeviceName_ = secureKeys?["AES"]?.encrypt(original: self.restoreDeviceName) ?? ""
																					let restoreParkNum_ = secureKeys?["AES"]?.encrypt(original: self.restoreParkNum) ?? ""
																					let restoreDate_ = secureKeys?["AES"]?.encrypt(original: self.restoreDate) ?? ""
																					let hireFee_ = secureKeys?["AES"]?.encrypt(original: self.hireFee) ?? ""
																					let operId_ = secureKeys?["AES"]?.encrypt(original: self.operId) ?? ""
																					let cityName_ = secureKeys?["AES"]?.encrypt(original: self.cityName) ?? ""
																					let sitePositionType_ = self.sitePositionType;
																					let restoreSitePosition_ = self.restoreSitePosition;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("userId=" + (userId_ ?? ""))
																					md5.append("&userPhone=" + (userPhone_ ?? ""))
																					md5.append("&cityCode=" + (cityCode_ ?? ""))
																					md5.append("&bikeId=" + (bikeId_ ?? ""))
																					md5.append("&loginType=" + (loginType_ ?? ""))
																					md5.append("&hireDeviceId=" + (hireDeviceId_ ?? ""))
																					md5.append("&hireDeviceName=" + (hireDeviceName_ ?? ""))
																					md5.append("&hireParkNum=" + (hireParkNum_ ?? ""))
																					md5.append("&hireDate=" + (hireDate_ ?? ""))
																					md5.append("&restoreDeviceId=" + (restoreDeviceId_ ?? ""))
																					md5.append("&restoreDeviceName=" + (restoreDeviceName_ ?? ""))
																					md5.append("&restoreParkNum=" + (restoreParkNum_ ?? ""))
																					md5.append("&restoreDate=" + (restoreDate_ ?? ""))
																					md5.append("&hireFee=" + (hireFee_ ?? ""))
																					md5.append("&operId=" + (operId_ ?? ""))
																					md5.append("&cityName=" + (cityName_ ?? ""))
																												
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostRestoreinfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:19,field:"userId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:19,value:userId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:19,field:"userId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:19,field:"userPhone",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:19,value:userPhone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:19,field:"userPhone",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:19,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:19,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:19,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:19,field:"bikeId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:19,value:bikeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:19,field:"bikeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:19,field:"loginType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:19,value:loginType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:19,field:"loginType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:19,field:"hireDeviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:19,value:hireDeviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:19,field:"hireDeviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:19,field:"hireDeviceName",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:19,value:hireDeviceName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:19,field:"hireDeviceName",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:19,field:"hireParkNum",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:19,value:hireParkNum_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:19,field:"hireParkNum",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:19,field:"hireDate",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:19,value:hireDate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:19,field:"hireDate",body:self))
												result.append(vo.onFieldBegin(.flat,index:10,length:19,field:"restoreDeviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:10,length:19,value:restoreDeviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:10,length:19,field:"restoreDeviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:11,length:19,field:"restoreDeviceName",body:self))
				result.append(vo.onFieldValue(.flat,index:11,length:19,value:restoreDeviceName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:11,length:19,field:"restoreDeviceName",body:self))
												result.append(vo.onFieldBegin(.flat,index:12,length:19,field:"restoreParkNum",body:self))
				result.append(vo.onFieldValue(.flat,index:12,length:19,value:restoreParkNum_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:12,length:19,field:"restoreParkNum",body:self))
												result.append(vo.onFieldBegin(.flat,index:13,length:19,field:"restoreDate",body:self))
				result.append(vo.onFieldValue(.flat,index:13,length:19,value:restoreDate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:13,length:19,field:"restoreDate",body:self))
												result.append(vo.onFieldBegin(.flat,index:14,length:19,field:"hireFee",body:self))
				result.append(vo.onFieldValue(.flat,index:14,length:19,value:hireFee_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:14,length:19,field:"hireFee",body:self))
												result.append(vo.onFieldBegin(.flat,index:15,length:19,field:"operId",body:self))
				result.append(vo.onFieldValue(.flat,index:15,length:19,value:operId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:15,length:19,field:"operId",body:self))
												result.append(vo.onFieldBegin(.flat,index:16,length:19,field:"cityName",body:self))
				result.append(vo.onFieldValue(.flat,index:16,length:19,value:cityName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:16,length:19,field:"cityName",body:self))
												result.append(vo.onFieldBegin(.flat,index:17,length:19,field:"sitePositionType",body:self))
				result.append(vo.onFieldValue(.flat,index:17,length:19,value:sitePositionType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:17,length:19,field:"sitePositionType",body:self))
												result.append(vo.onFieldBegin(.flat,index:18,length:19,field:"restoreSitePosition",body:self))
				result.append(vo.onFieldValue(.flat,index:18,length:19,value:restoreSitePosition_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:18,length:19,field:"restoreSitePosition",body:self))
									result.append(vo.onFieldBegin(.flat,index:19,length:19,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:19,length:19,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:19,length:19,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostRestoreinfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetRestoreinfo : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    							open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/restoreinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/restoreinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
																											orderId = visitableSource.getValue("orderId")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostErrorhdlinfo : BaseITWebAPIBody {
	
	//
						open var userId:String?
    							open var userPhone:String?
    							open var cityCode:String?
    							open var bikeId:String?
    							open var loginType:String?
    							open var errorhdlDeviceId:String?
    							open var errorhdlDeviceName:String?
    							open var errorhdlParkNum:String?
    							open var errorhdlDate:String?
    							open var operId:String?
    							open var cityName:String?
    							open var sitePositionType:String?
    							open var hireSitePosition:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/errorhdlinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/errorhdlinfo"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let userId_ = self.userId;
																					let userPhone_ = self.userPhone;
																					let cityCode_ = self.cityCode;
																					let bikeId_ = self.bikeId;
																					let loginType_ = self.loginType;
																					let errorhdlDeviceId_ = self.errorhdlDeviceId;
																					let errorhdlDeviceName_ = self.errorhdlDeviceName;
																					let errorhdlParkNum_ = self.errorhdlParkNum;
																					let errorhdlDate_ = self.errorhdlDate;
																					let operId_ = self.operId;
																					let cityName_ = secureKeys?["AES"]?.encrypt(original: self.cityName) ?? ""
																					let sitePositionType_ = self.sitePositionType;
																					let hireSitePosition_ = self.hireSitePosition;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("userId=" + (userId_ ?? ""))
																					md5.append("&userPhone=" + (userPhone_ ?? ""))
																					md5.append("&cityCode=" + (cityCode_ ?? ""))
																					md5.append("&bikeId=" + (bikeId_ ?? ""))
																					md5.append("&loginType=" + (loginType_ ?? ""))
																					md5.append("&errorhdlDeviceId=" + (errorhdlDeviceId_ ?? ""))
																					md5.append("&errorhdlDeviceName=" + (errorhdlDeviceName_ ?? ""))
																					md5.append("&errorhdlParkNum=" + (errorhdlParkNum_ ?? ""))
																					md5.append("&errorhdlDate=" + (errorhdlDate_ ?? ""))
																					md5.append("&operId=" + (operId_ ?? ""))
																					md5.append("&cityName=" + (cityName_ ?? ""))
																												
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostErrorhdlinfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:14,field:"userId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:14,value:userId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:14,field:"userId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:14,field:"userPhone",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:14,value:userPhone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:14,field:"userPhone",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:14,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:14,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:14,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:14,field:"bikeId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:14,value:bikeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:14,field:"bikeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:14,field:"loginType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:14,value:loginType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:14,field:"loginType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:14,field:"errorhdlDeviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:14,value:errorhdlDeviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:14,field:"errorhdlDeviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:14,field:"errorhdlDeviceName",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:14,value:errorhdlDeviceName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:14,field:"errorhdlDeviceName",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:14,field:"errorhdlParkNum",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:14,value:errorhdlParkNum_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:14,field:"errorhdlParkNum",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:14,field:"errorhdlDate",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:14,value:errorhdlDate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:14,field:"errorhdlDate",body:self))
												result.append(vo.onFieldBegin(.flat,index:10,length:14,field:"operId",body:self))
				result.append(vo.onFieldValue(.flat,index:10,length:14,value:operId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:10,length:14,field:"operId",body:self))
												result.append(vo.onFieldBegin(.flat,index:11,length:14,field:"cityName",body:self))
				result.append(vo.onFieldValue(.flat,index:11,length:14,value:cityName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:11,length:14,field:"cityName",body:self))
												result.append(vo.onFieldBegin(.flat,index:12,length:14,field:"sitePositionType",body:self))
				result.append(vo.onFieldValue(.flat,index:12,length:14,value:sitePositionType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:12,length:14,field:"sitePositionType",body:self))
												result.append(vo.onFieldBegin(.flat,index:13,length:14,field:"hireSitePosition",body:self))
				result.append(vo.onFieldValue(.flat,index:13,length:14,value:hireSitePosition_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:13,length:14,field:"hireSitePosition",body:self))
									result.append(vo.onFieldBegin(.flat,index:14,length:14,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:14,length:14,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:14,length:14,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostErrorhdlinfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetErrorhdlinfo : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/errorhdlinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/errorhdlinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostPerTripRecords : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/pertrips"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/pertrips"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let beginindex_ = secureKeys?["AES"]?.encrypt(original: self.beginindex) ?? ""
																					let retcount_ = secureKeys?["AES"]?.encrypt(original: self.retcount) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&beginindex=" + (beginindex_ ?? ""))
																					md5.append("&retcount=" + (retcount_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostPerTripRecords",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"retcount",body:self))
									result.append(vo.onFieldBegin(.flat,index:6,length:6,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:6,length:6,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:6,length:6,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostPerTripRecords",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetPerTripRecords : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikecaPerTripRecord]()
			//>-----
								open var tempLockPwd:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/pertrips"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/pertrips"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("datacount"))
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( PerTripRecord (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
																						tempLockPwd = visitableSource.getValue("tempLockPwd")
															}

	//-------> list
			    		    		    			    open func addData(subBody:PerTripRecord) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [PerTripRecord]{
	        return data
	    }
	        		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikecaPerTripRecord : BaseITWebAPIBody {
	
	//
						open var bikeId:String?
    							open var hireStatus:String?
    							open var hireTime:String?
    							open var restoreTime:String?
    							open var hireStationId:String?
    							open var hireStationName:String?
    							open var hireParkNum:String?
    							open var hireCoord:String?
    							open var restoreStationId:String?
    							open var restoreStationName:String?
    							open var restoreParkNum:String?
    							open var restoreCoord:String?
    							open var money:String?
    							open var orderId:String?
    							open var orderStatus:String?
    							open var cityCode:String?
    							open var hLockType:String?
    							open var rLockType:String?
    							open var id:String?
    							open var reletId:String?
    							open var releteTime:String?
    							open var surplusSecond:String?
    							open var releteEndTime:String?
    							open var befDiscountMoney:String?
    							open var dispatchFee:String?
    							open var cardPreFee:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/pertrips"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/pertrips"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		bikeId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("bikeId"))
																											hireStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("hireStatus"))
																											hireTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("hireTime"))
																											restoreTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("restoreTime"))
																											hireStationId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("hireStationId"))
																											hireStationName = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("hireStationName"))
																											hireParkNum = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("hireParkNum"))
																											hireCoord = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("hireCoord"))
																											restoreStationId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("restoreStationId"))
																											restoreStationName = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("restoreStationName"))
																											restoreParkNum = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("restoreParkNum"))
																											restoreCoord = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("restoreCoord"))
																											money = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("money"))
																											orderId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderId"))
																											orderStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderStatus"))
																											cityCode = visitableSource.getValue("cityCode")
																											hLockType = visitableSource.getValue("hLockType")
																											rLockType = visitableSource.getValue("rLockType")
																											id = visitableSource.getValue("id")
																											reletId = visitableSource.getValue("reletId")
																											releteTime = visitableSource.getValue("releteTime")
																											surplusSecond = visitableSource.getValue("surplusSecond")
																											releteEndTime = visitableSource.getValue("releteEndTime")
																											befDiscountMoney = visitableSource.getValue("befDiscountMoney")
																											dispatchFee = visitableSource.getValue("dispatchFee")
																											cardPreFee = visitableSource.getValue("cardPreFee")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
											}

		
open class BikecaPostPerTripRecordsNew : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/pertripsNew"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/pertripsNew"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
																					let appId_ = self.appId;
																					let beginindex_ = self.beginindex;
																					let retcount_ = self.retcount;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostPerTripRecordsNew",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"retcount",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostPerTripRecordsNew",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetPerTripRecordsNew : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikecaPerTripRecordNew]()
			//>-----
								open var tempLockPwd:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/pertripsNew"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/pertripsNew"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( PerTripRecordNew (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
																						tempLockPwd = visitableSource.getValue("tempLockPwd")
															}

	//-------> list
			    		    		    			    open func addData(subBody:PerTripRecordNew) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [PerTripRecordNew]{
	        return data
	    }
	        		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikecaPerTripRecordNew : BaseITWebAPIBody {
	
	//
						open var bikeId:String?
    							open var hireStatus:String?
    							open var hireTime:String?
    							open var restoreTime:String?
    							open var hireStationId:String?
    							open var hireStationName:String?
    							open var hireParkNum:String?
    							open var hireCoord:String?
    							open var restoreStationId:String?
    							open var restoreStationName:String?
    							open var restoreParkNum:String?
    							open var restoreCoord:String?
    							open var money:String?
    							open var orderId:String?
    							open var orderStatus:String?
    							open var cityCode:String?
    							open var hLockType:String?
    							open var rLockType:String?
    							open var id:String?
    							open var reletId:String?
    							open var releteTime:String?
    							open var surplusSecond:String?
    							open var releteEndTime:String?
    							open var befDiscountMoney:String?
    							open var dispatchFee:String?
    							open var cardPreFee:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/pertripsNew"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/pertripsNew"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		bikeId = visitableSource.getValue("bikeId")
																											hireStatus = visitableSource.getValue("hireStatus")
																											hireTime = visitableSource.getValue("hireTime")
																											restoreTime = visitableSource.getValue("restoreTime")
																											hireStationId = visitableSource.getValue("hireStationId")
																											hireStationName = visitableSource.getValue("hireStationName")
																											hireParkNum = visitableSource.getValue("hireParkNum")
																											hireCoord = visitableSource.getValue("hireCoord")
																											restoreStationId = visitableSource.getValue("restoreStationId")
																											restoreStationName = visitableSource.getValue("restoreStationName")
																											restoreParkNum = visitableSource.getValue("restoreParkNum")
																											restoreCoord = visitableSource.getValue("restoreCoord")
																											money = visitableSource.getValue("money")
																											orderId = visitableSource.getValue("orderId")
																											orderStatus = visitableSource.getValue("orderStatus")
																											cityCode = visitableSource.getValue("cityCode")
																											hLockType = visitableSource.getValue("hLockType")
																											rLockType = visitableSource.getValue("rLockType")
																											id = visitableSource.getValue("id")
																											reletId = visitableSource.getValue("reletId")
																											releteTime = visitableSource.getValue("releteTime")
																											surplusSecond = visitableSource.getValue("surplusSecond")
																											releteEndTime = visitableSource.getValue("releteEndTime")
																											befDiscountMoney = visitableSource.getValue("befDiscountMoney")
																											dispatchFee = visitableSource.getValue("dispatchFee")
																											cardPreFee = visitableSource.getValue("cardPreFee")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
											}

		
open class BikecaPostCheckOrderStatus : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var orderId:String?
    							open var coupUsedId:String?
    							open var coupId:String?
    							open var finalPayMoney:String?
    							open var coupType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkOrderStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkOrderStatus"
        	}

	//-------> list
			    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let orderId_ = secureKeys?["AES"]?.encrypt(original: self.orderId) ?? ""
																					let coupUsedId_ = self.coupUsedId;
																					let coupId_ = self.coupId;
																					let finalPayMoney_ = self.finalPayMoney;
																					let coupType_ = self.coupType;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&orderId=" + (orderId_ ?? ""))
																																										
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostCheckOrderStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:9,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:9,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:9,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:9,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:9,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:9,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:9,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:9,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:9,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:9,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:9,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:9,field:"orderId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:9,field:"coupUsedId",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:9,value:coupUsedId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:9,field:"coupUsedId",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:9,field:"coupId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:9,value:coupId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:9,field:"coupId",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:9,field:"finalPayMoney",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:9,value:finalPayMoney_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:9,field:"finalPayMoney",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:9,field:"coupType",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:9,value:coupType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:9,field:"coupType",body:self))
									result.append(vo.onFieldBegin(.flat,index:9,length:9,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:9,length:9,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:9,length:9,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostCheckOrderStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetCheckOrderStatus : BaseITWebAPIBody {
	
	//
												open var orderStatus:String?
    							open var bizStatus:String?
    							open var openTime:String?
    							open var bizMoney:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkOrderStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkOrderStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											orderStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderStatus"))
																											bizStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("bizStatus"))
																											openTime = visitableSource.getValue("openTime")
																											bizMoney = visitableSource.getValue("bizMoney")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostCheckCertifyStatus : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var channelType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkCertifyStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkCertifyStatus"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let channelType_ = secureKeys?["AES"]?.encrypt(original: self.channelType) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&channelType=" + (channelType_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostCheckCertifyStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"channelType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:channelType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"channelType",body:self))
									result.append(vo.onFieldBegin(.flat,index:5,length:5,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:5,length:5,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:5,length:5,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostCheckCertifyStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetCheckCertifyStatus : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkCertifyStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkCertifyStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("reqStatus"))
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostCheckTodayCyc : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkTodayCyc"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkTodayCyc"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostCheckTodayCyc",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"accessToken",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostCheckTodayCyc",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetCheckTodayCyc : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkTodayCyc"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkTodayCyc"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostReletPriceList : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serviceId:String?
    							open var bikeType:String?
    							open var userId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/reletPriceList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/reletPriceList"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let bikeType_ = secureKeys?["AES"]?.encrypt(original: self.bikeType) ?? ""
																					let userId_ = self.userId;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("appId=" + (appId_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&bikeType=" + (bikeType_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostReletPriceList",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"bikeType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:bikeType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"bikeType",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"userId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:userId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"userId",body:self))
									result.append(vo.onFieldBegin(.flat,index:5,length:5,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:5,length:5,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:5,length:5,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostReletPriceList",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetReletPriceList : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikecaReletPriceRecord]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/reletPriceList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/reletPriceList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( ReletPriceRecord (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:ReletPriceRecord) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [ReletPriceRecord]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikecaReletPriceRecord : BaseITWebAPIBody {
	
	//
						open var id:String?
    							open var reletHour:String?
    							open var reletPrice:String?
    							open var display:String?
    							open var bikeType:String?
    							open var reletMode:String?
    							open var startTime:String?
    							open var endTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/reletPriceList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/reletPriceList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		id = visitableSource.getValue("id")
																											reletHour = visitableSource.getValue("reletHour")
																											reletPrice = visitableSource.getValue("reletPrice")
																											display = visitableSource.getValue("display")
																											bikeType = visitableSource.getValue("bikeType")
																											reletMode = visitableSource.getValue("reletMode")
																											startTime = visitableSource.getValue("startTime")
																											endTime = visitableSource.getValue("endTime")
															}

	//-------> list
			    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikecaPostInsertReletRecord : BaseITWebAPIBody {
	
	//
									open var tripId:String?
    							open var reletPrice:String?
    							open var reletHour:String?
    							open var bikeType:String?
    							open var reletStartTime:String?
    							open var reletEndTime:String?
    							open var reletMode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/insertReletRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/insertReletRecord"
        	}

	//-------> list
			    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let tripId_ = secureKeys?["AES"]?.encrypt(original: self.tripId) ?? ""
																					let reletPrice_ = secureKeys?["AES"]?.encrypt(original: self.reletPrice) ?? ""
																					let reletHour_ = secureKeys?["AES"]?.encrypt(original: self.reletHour) ?? ""
																					let bikeType_ = secureKeys?["AES"]?.encrypt(original: self.bikeType) ?? ""
																					let reletStartTime_ = self.reletStartTime;
																					let reletEndTime_ = self.reletEndTime;
																					let reletMode_ = self.reletMode;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&tripId=" + (tripId_ ?? ""))
																					md5.append("&reletPrice=" + (reletPrice_ ?? ""))
																					md5.append("&reletHour=" + (reletHour_ ?? ""))
																					md5.append("&bikeType=" + (bikeType_ ?? ""))
																																			
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostInsertReletRecord",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:9,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:9,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:9,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:9,field:"tripId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:9,value:tripId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:9,field:"tripId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:9,field:"reletPrice",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:9,value:reletPrice_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:9,field:"reletPrice",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:9,field:"reletHour",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:9,value:reletHour_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:9,field:"reletHour",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:9,field:"bikeType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:9,value:bikeType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:9,field:"bikeType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:9,field:"reletStartTime",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:9,value:reletStartTime_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:9,field:"reletStartTime",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:9,field:"reletEndTime",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:9,value:reletEndTime_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:9,field:"reletEndTime",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:9,field:"reletMode",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:9,value:reletMode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:9,field:"reletMode",body:self))
									result.append(vo.onFieldBegin(.flat,index:9,length:9,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:9,length:9,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:9,length:9,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostInsertReletRecord",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetInsertReletRecord : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/insertReletRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/insertReletRecord"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostDeleteReletRecord : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/deleteReletRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/deleteReletRecord"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostDeleteReletRecord",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"accessToken",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostDeleteReletRecord",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetDeleteReletRecord : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/deleteReletRecord"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/deleteReletRecord"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostGetPriceList : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getPriceList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getPriceList"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("appId=" + (appId_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostGetPriceList",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"serviceId",body:self))
									result.append(vo.onFieldBegin(.flat,index:3,length:3,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:3,length:3,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:3,length:3,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostGetPriceList",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetGetPriceList : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikecaPriceRecord]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getPriceList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getPriceList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( PriceRecord (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:PriceRecord) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [PriceRecord]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikecaPriceRecord : BaseITWebAPIBody {
	
	//
						open var hireTimes:String?
    							open var price:String?
    							open var bikeType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getPriceList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getPriceList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		hireTimes = visitableSource.getValue("hireTimes")
																											price = visitableSource.getValue("price")
																											bikeType = visitableSource.getValue("bikeType")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikecaPostGetCouponUser : BaseITWebAPIBody {
	
	//
						open var serviceId:String?
    							open var time:String?
    							open var startTime:String?
    							open var endTime:String?
    							open var nowDate:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getCouponUser"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getCouponUser"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let time_ = secureKeys?["AES"]?.encrypt(original: self.time) ?? ""
																					let startTime_ = secureKeys?["AES"]?.encrypt(original: self.startTime) ?? ""
																					let endTime_ = secureKeys?["AES"]?.encrypt(original: self.endTime) ?? ""
																					let nowDate_ = secureKeys?["AES"]?.encrypt(original: self.nowDate) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("serviceId=" + (serviceId_ ?? ""))
																					md5.append("&time=" + (time_ ?? ""))
																					md5.append("&startTime=" + (startTime_ ?? ""))
																					md5.append("&endTime=" + (endTime_ ?? ""))
																					md5.append("&nowDate=" + (nowDate_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostGetCouponUser",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"time",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:time_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"time",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"startTime",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:startTime_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"startTime",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"endTime",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:endTime_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"endTime",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"nowDate",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:nowDate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"nowDate",body:self))
									result.append(vo.onFieldBegin(.flat,index:6,length:6,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:6,length:6,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:6,length:6,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostGetCouponUser",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetGetCouponUser : BaseITWebAPIBody {
	
	//
												open var userIds:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getCouponUser"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getCouponUser"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											userIds = visitableSource.getValue("userIds")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostGetUserInfo : BaseITWebAPIBody {
	
	//
						open var phone:String?
    							open var userId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getUserInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getUserInfo"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let phone_ = secureKeys?["AES"]?.encrypt(original: self.phone) ?? ""
																					let userId_ = secureKeys?["AES"]?.encrypt(original: self.userId) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("phone=" + (phone_ ?? ""))
																					md5.append("&userId=" + (userId_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostGetUserInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"phone",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:phone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"phone",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"userId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:userId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"userId",body:self))
									result.append(vo.onFieldBegin(.flat,index:3,length:3,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:3,length:3,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:3,length:3,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostGetUserInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetGetUserInfo : BaseITWebAPIBody {
	
	//
												open var phone:String?
    							open var userId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getUserInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getUserInfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											phone = visitableSource.getValue("phone")
																											userId = visitableSource.getValue("userId")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostTripOverView : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/tripOverView"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/tripOverView"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostTripOverView",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"appId",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostTripOverView",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetTripOverView : BaseITWebAPIBody {
	
	//
												open var tripTotalNum:String?
    							open var rideRange:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/tripOverView"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/tripOverView"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											tripTotalNum = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("tripTotalNum"))
																											rideRange = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("rideRange"))
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostQueryProgress : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/queryProgress"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/queryProgress"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostQueryProgress",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"accessToken",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostQueryProgress",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetQueryProgress : BaseITWebAPIBody {
	
	//
						open var refundStatusAndTime:String?
    							open var refundStatus:String?
    								
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/queryProgress"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/queryProgress"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		refundStatusAndTime = visitableSource.getValue("refundStatusAndTime")
																											refundStatus = visitableSource.getValue("refundStatus")
																											retmsg = visitableSource.getValue("retmsg")
																											retcode = visitableSource.getValue("retcode")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostRevokeRefund : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/revokeRefund"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/revokeRefund"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostRevokeRefund",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"accessToken",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostRevokeRefund",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetRevokeRefund : BaseITWebAPIBody {
	
	//
						open var bizMoney:String?
    							open var cancelTime:String?
    								
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/revokeRefund"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/revokeRefund"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		bizMoney = visitableSource.getValue("bizMoney")
																											cancelTime = visitableSource.getValue("cancelTime")
																											retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostChangeRefund : BaseITWebAPIBody {
	
	//
						open var userId:String?
    							open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/changeRefund"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/changeRefund"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let userId_ = self.userId;
																					let orderId_ = self.orderId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostChangeRefund",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"userId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:userId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"userId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"orderId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostChangeRefund",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetChangeRefund : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/changeRefund"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/changeRefund"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostUpdateBizStatus : BaseITWebAPIBody {
	
	//
									open var depositType:String?
    							open var serviceId:String?
    							open var bizType:String?
    							open var bizStatus:String?
    							open var appId:String?
    							open var terminalType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/inner/updateBizStatusByService"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/inner/updateBizStatusByService"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let depositType_ = secureKeys?["AES"]?.encrypt(original: self.depositType) ?? ""
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let bizType_ = secureKeys?["AES"]?.encrypt(original: self.bizType) ?? ""
																					let bizStatus_ = secureKeys?["AES"]?.encrypt(original: self.bizStatus) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let terminalType_ = self.terminalType;
									
		//====   md5 check   ====
					var md5:[String] = []
																						md5.append("depositType=" + (depositType_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&bizType=" + (bizType_ ?? ""))
																					md5.append("&bizStatus=" + (bizStatus_ ?? ""))
																												
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostUpdateBizStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"depositType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:depositType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"depositType",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"bizType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:bizType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"bizType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"bizStatus",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:bizStatus_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"bizStatus",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"terminalType",body:self))
									result.append(vo.onFieldBegin(.flat,index:8,length:8,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:8,length:8,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:8,length:8,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostUpdateBizStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetUpdateBizStatus : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/inner/updateBizStatusByService"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/inner/updateBizStatusByService"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostUpdateIbikeUserStatus : BaseITWebAPIBody {
	
	//
						open var userPhone:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/inner/updateIbikeUserStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/inner/updateIbikeUserStatus"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let userPhone_ = self.userPhone;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostUpdateIbikeUserStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"userPhone",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:userPhone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"userPhone",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostUpdateIbikeUserStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetUpdateIbikeUserStatus : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/inner/updateIbikeUserStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/inner/updateIbikeUserStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostGetInvitationInfo : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/extra/getInvitationInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/extra/getInvitationInfo"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostGetInvitationInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"accessToken",body:self))
									result.append(vo.onFieldBegin(.flat,index:2,length:2,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:2,length:2,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:2,length:2,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostGetInvitationInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetGetInvitationInfo : BaseITWebAPIBody {
	
	//
												open var inviteStatus:String?
    							open var inviteCode:String?
    							open var oppositePhone:String?
    							open var exprRemain:String?
    							open var exprBeginTime:String?
    							open var exprEndTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/extra/getInvitationInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/extra/getInvitationInfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											inviteStatus = visitableSource.getValue("inviteStatus")
																											inviteCode = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("inviteCode"))
																											oppositePhone = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("oppositePhone"))
																											exprRemain = visitableSource.getValue("exprRemain")
																											exprBeginTime = visitableSource.getValue("exprBeginTime")
																											exprEndTime = visitableSource.getValue("exprEndTime")
															}

	//-------> list
			    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostInviteExpr : BaseITWebAPIBody {
	
	//
									open var inviteType:String?
    							open var vCode:String?
    							open var oppositePhone:String?
    							open var inviteCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/extra/inviteExpr"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/extra/inviteExpr"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let inviteType_ = self.inviteType;
																					let vCode_ = self.vCode;
																					let oppositePhone_ = secureKeys?["AES"]?.encrypt(original: self.oppositePhone) ?? ""
																					let inviteCode_ = secureKeys?["AES"]?.encrypt(original: self.inviteCode) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																																										
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostInviteExpr",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"inviteType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:inviteType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"inviteType",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"vCode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:vCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"vCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"oppositePhone",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:oppositePhone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"oppositePhone",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"inviteCode",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:inviteCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"inviteCode",body:self))
									result.append(vo.onFieldBegin(.flat,index:6,length:6,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:6,length:6,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:6,length:6,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostInviteExpr",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetInviteExpr : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    							open var inviteStatus:String?
    							open var inviteCode:String?
    							open var oppositePhone:String?
    							open var exprRemain:String?
    							open var exprBeginTime:String?
    							open var exprEndTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/extra/inviteExpr"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/extra/inviteExpr"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("bizStatus"))
																											inviteStatus = visitableSource.getValue("inviteStatus")
																											inviteCode = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("inviteCode"))
																											oppositePhone = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("oppositePhone"))
																											exprRemain = visitableSource.getValue("exprRemain")
																											exprBeginTime = visitableSource.getValue("exprBeginTime")
																											exprEndTime = visitableSource.getValue("exprEndTime")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostIntimateBind : BaseITWebAPIBody {
	
	//
									open var reqType:String?
    							open var intimatePhone:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/extra/intimateBind"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/extra/intimateBind"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let reqType_ = self.reqType;
																					let intimatePhone_ = self.intimatePhone;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostIntimateBind",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"reqType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:reqType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"reqType",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"intimatePhone",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:intimatePhone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"intimatePhone",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostIntimateBind",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetIntimateBind : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var oldIntimatePhone:String?
    							open var newIntimatePhone:String?
    							open var intimateBindStatus:String?
    							open var exprBeginTime:String?
    							open var exprEndTime:String?
    							open var exprRemain:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/extra/intimateBind"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/extra/intimateBind"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											oldIntimatePhone = visitableSource.getValue("oldIntimatePhone")
																											newIntimatePhone = visitableSource.getValue("newIntimatePhone")
																											intimateBindStatus = visitableSource.getValue("intimateBindStatus")
																											exprBeginTime = visitableSource.getValue("exprBeginTime")
																											exprEndTime = visitableSource.getValue("exprEndTime")
																											exprRemain = visitableSource.getValue("exprRemain")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostUserBuyCard : BaseITWebAPIBody {
	
	//
									open var cardId:String?
    							open var appId:String?
    							open var serviceId:String?
    							open var walletConfigId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/userBuyCard"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/userBuyCard"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let cardId_ = self.cardId;
																					let appId_ = self.appId;
																					let serviceId_ = self.serviceId;
																					let walletConfigId_ = self.walletConfigId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostUserBuyCard",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"cardId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:cardId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"cardId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"walletConfigId",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:walletConfigId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"walletConfigId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostUserBuyCard",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetUserBuyCard : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/userBuyCard"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/userBuyCard"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											orderId = visitableSource.getValue("orderId")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostQueryCardDaysRemainingd : BaseITWebAPIBody {
	
	//
									open var grade:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryCardDaysRemaining"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryCardDaysRemaining"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let grade_ = self.grade;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostQueryCardDaysRemainingd",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"grade",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:grade_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"grade",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostQueryCardDaysRemainingd",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetQueryCardDaysRemaining : BaseITWebAPIBody {
	
	//
												open var userCardStatus:String?
    							open var daysRemaining:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryCardDaysRemaining"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryCardDaysRemaining"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											userCardStatus = visitableSource.getValue("userCardStatus")
																											daysRemaining = visitableSource.getValue("daysRemaining")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostQueryUserCard : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryUserCard"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryUserCard"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostQueryUserCard",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"accessToken",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostQueryUserCard",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetQueryUserCard : BaseITWebAPIBody {
	
	//
												open var userCardStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryUserCard"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryUserCard"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											userCardStatus = visitableSource.getValue("userCardStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostQueryCardAndDaysRemainingd : BaseITWebAPIBody {
	
	//
									open var appId:String?
    							open var serviceId:String?
    							open var grade:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryCardAndDaysRemaining"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryCardAndDaysRemaining"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let appId_ = self.appId;
																					let serviceId_ = self.serviceId;
																					let grade_ = self.grade;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostQueryCardAndDaysRemainingd",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"grade",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:grade_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"grade",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostQueryCardAndDaysRemainingd",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetQueryCardAndDaysRemaining : BaseITWebAPIBody {
	
	//
												open var daysRemaining:String?
    				    		//----->list
			fileprivate var data = [BikecaGetAPPCardDetailList]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryCardAndDaysRemaining"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryCardAndDaysRemaining"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											daysRemaining = visitableSource.getValue("daysRemaining")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( GetAPPCardDetailList (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:GetAPPCardDetailList) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [GetAPPCardDetailList]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikecaGetAPPCardDetailList : BaseITWebAPIBody {
	
	//
						open var id:String?
    							open var bikeType:String?
    							open var cardType:String?
    							open var cardName:String?
    							open var cardDetailType:String?
    							open var cardTimes:String?
    							open var cardHour:String?
    							open var cardRentPrice:String?
    							open var cardDiscount:String?
    							open var display:String?
    							open var remark:String?
    							open var grade:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryCardAndDaysRemaining"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/queryCardAndDaysRemaining"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		id = visitableSource.getValue("id")
																											bikeType = visitableSource.getValue("bikeType")
																											cardType = visitableSource.getValue("cardType")
																											cardName = visitableSource.getValue("cardName")
																											cardDetailType = visitableSource.getValue("cardDetailType")
																											cardTimes = visitableSource.getValue("cardTimes")
																											cardHour = visitableSource.getValue("cardHour")
																											cardRentPrice = visitableSource.getValue("cardRentPrice")
																											cardDiscount = visitableSource.getValue("cardDiscount")
																											display = visitableSource.getValue("display")
																											remark = visitableSource.getValue("remark")
																											grade = visitableSource.getValue("grade")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikecaPostGetCardDetailList : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serviceId:String?
    							open var grade:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/getCardDetailList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/getCardDetailList"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = self.appId;
																					let serviceId_ = self.serviceId;
																					let grade_ = self.grade;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostGetCardDetailList",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"grade",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:grade_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"grade",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostGetCardDetailList",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetGetCardDetailList : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikecaGetCardDetailList]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/getCardDetailList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/getCardDetailList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( GetCardDetailList (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:GetCardDetailList) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [GetCardDetailList]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikecaGetCardDetailList : BaseITWebAPIBody {
	
	//
						open var id:String?
    							open var bikeType:String?
    							open var grade:String?
    							open var cardType:String?
    							open var cardName:String?
    							open var cardDetailType:String?
    							open var cardTimes:String?
    							open var cardHour:String?
    							open var cardRentPrice:String?
    							open var cardDiscount:String?
    							open var display:String?
    							open var remark:String?
    							open var limitedTimeOffer:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/getCardDetailList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/getCardDetailList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		id = visitableSource.getValue("id")
																											bikeType = visitableSource.getValue("bikeType")
																											grade = visitableSource.getValue("grade")
																											cardType = visitableSource.getValue("cardType")
																											cardName = visitableSource.getValue("cardName")
																											cardDetailType = visitableSource.getValue("cardDetailType")
																											cardTimes = visitableSource.getValue("cardTimes")
																											cardHour = visitableSource.getValue("cardHour")
																											cardRentPrice = visitableSource.getValue("cardRentPrice")
																											cardDiscount = visitableSource.getValue("cardDiscount")
																											display = visitableSource.getValue("display")
																											remark = visitableSource.getValue("remark")
																											limitedTimeOffer = visitableSource.getValue("limitedTimeOffer")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikecaPostGetUserBuyCardList : BaseITWebAPIBody {
	
	//
									open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/getUserBuyCardList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/getUserBuyCardList"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let beginindex_ = self.beginindex;
																					let retcount_ = self.retcount;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostGetUserBuyCardList",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"retcount",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostGetUserBuyCardList",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetGetUserBuyCardList : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikecaGetUserBuyCardList]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/getUserBuyCardList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/getUserBuyCardList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( GetUserBuyCardList (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:GetUserBuyCardList) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [GetUserBuyCardList]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikecaGetUserBuyCardList : BaseITWebAPIBody {
	
	//
						open var buyDays:String?
    							open var cardName:String?
    							open var Price:String?
    							open var createTime:String?
    							open var buyChannel:String?
    							open var rechargeChannel:String?
    							open var grade:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/getUserBuyCardList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/getUserBuyCardList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		buyDays = visitableSource.getValue("buyDays")
																											cardName = visitableSource.getValue("cardName")
																											Price = visitableSource.getValue("Price")
																											createTime = visitableSource.getValue("createTime")
																											buyChannel = visitableSource.getValue("buyChannel")
																											rechargeChannel = visitableSource.getValue("rechargeChannel")
																											grade = visitableSource.getValue("grade")
															}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikecaPostCheckBuyOrderStatus : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var type:String?
    							open var orderId:String?
    							open var cardId:String?
    							open var walletConfigId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkBuyOrderStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkBuyOrderStatus"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let type_ = secureKeys?["AES"]?.encrypt(original: self.type) ?? ""
																					let orderId_ = secureKeys?["AES"]?.encrypt(original: self.orderId) ?? ""
																					let cardId_ = secureKeys?["AES"]?.encrypt(original: self.cardId) ?? ""
																					let walletConfigId_ = self.walletConfigId;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&type=" + (type_ ?? ""))
																					md5.append("&orderId=" + (orderId_ ?? ""))
																					md5.append("&cardId=" + (cardId_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostCheckBuyOrderStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"type",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"orderId",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"cardId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:cardId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"cardId",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"walletConfigId",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:walletConfigId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"walletConfigId",body:self))
									result.append(vo.onFieldBegin(.flat,index:8,length:8,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:8,length:8,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:8,length:8,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostCheckBuyOrderStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetCheckBuyOrderStatus : BaseITWebAPIBody {
	
	//
												open var orderStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkBuyOrderStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkBuyOrderStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											orderStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderStatus"))
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostGetCommonConfigList : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/config/getCommonConfigList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/config/getCommonConfigList"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = self.appId;
																					let serviceId_ = self.serviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostGetCommonConfigList",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"serviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostGetCommonConfigList",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetGetCommonConfigList : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikecaGetCommonConfigList]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/config/getCommonConfigList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/config/getCommonConfigList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( GetCommonConfigList (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:GetCommonConfigList) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [GetCommonConfigList]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikecaGetCommonConfigList : BaseITWebAPIBody {
	
	//
						open var name:String?
    							open var value:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/config/getCommonConfigList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/config/getCommonConfigList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		name = visitableSource.getValue("name")
																											value = visitableSource.getValue("value")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikecaPostCheckCloudPosOrderStatus : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var type:String?
    							open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkCloudPosOrderStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkCloudPosOrderStatus"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let type_ = secureKeys?["AES"]?.encrypt(original: self.type) ?? ""
																					let orderId_ = secureKeys?["AES"]?.encrypt(original: self.orderId) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&type=" + (type_ ?? ""))
																					md5.append("&orderId=" + (orderId_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostCheckCloudPosOrderStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"type",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"orderId",body:self))
									result.append(vo.onFieldBegin(.flat,index:6,length:6,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:6,length:6,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:6,length:6,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostCheckCloudPosOrderStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetCheckCloudPosOrderStatus : BaseITWebAPIBody {
	
	//
												open var orderStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkCloudPosOrderStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/checkCloudPosOrderStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											orderStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderStatus"))
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostUseWalletForBusiness : BaseITWebAPIBody {
	
	//
									open var orderId:String?
    							open var usedChannel:String?
    							open var serviceId:String?
    							open var coupUsedId:String?
    							open var terminaltype:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/useWalletForBusiness"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/useWalletForBusiness"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let orderId_ = self.orderId;
																					let usedChannel_ = self.usedChannel;
																					let serviceId_ = self.serviceId;
																					let coupUsedId_ = self.coupUsedId;
																					let terminaltype_ = self.terminaltype;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostUseWalletForBusiness",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:7,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:7,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:7,field:"orderId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:7,field:"usedChannel",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:7,value:usedChannel_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:7,field:"usedChannel",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:7,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:7,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:7,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:7,field:"coupUsedId",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:7,value:coupUsedId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:7,field:"coupUsedId",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:7,field:"terminaltype",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:7,value:terminaltype_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:7,field:"terminaltype",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostUseWalletForBusiness",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetUseWalletForBusiness : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/useWalletForBusiness"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/useWalletForBusiness"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostFreeCardActivity : BaseITWebAPIBody {
	
	//
									open var buyChannel:String?
    							open var serviceId:String?
    							open var remark:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/freeCardActivity"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/freeCardActivity"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let buyChannel_ = self.buyChannel;
																					let serviceId_ = self.serviceId;
																					let remark_ = self.remark;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostFreeCardActivity",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"buyChannel",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:buyChannel_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"buyChannel",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"remark",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:remark_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"remark",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostFreeCardActivity",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetFreeCardActivity : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/freeCardActivity"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/card/freeCardActivity"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostOpenBizAgree : BaseITWebAPIBody {
	
	//
									open var bizType:String?
    							open var version:String?
    							open var terminalType:String?
    							open var pamrams:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/openBizAgree"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/openBizAgree"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let bizType_ = self.bizType;
																					let version_ = self.version;
																					let terminalType_ = self.terminalType;
																					let pamrams_ = self.pamrams;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostOpenBizAgree",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"bizType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:bizType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"bizType",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"version",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:version_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"version",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"pamrams",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:pamrams_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"pamrams",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostOpenBizAgree",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetOpenBizAgree : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/openBizAgree"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/openBizAgree"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostGetBizAgree : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getBizAgree"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getBizAgree"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostGetBizAgree",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"accessToken",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostGetBizAgree",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetGetBizAgree : BaseITWebAPIBody {
	
	//
												open var agreeExtra:String?
    							open var baseExtra:String?
    							open var rentFlag:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getBizAgree"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getBizAgree"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											agreeExtra = visitableSource.getValue("agreeExtra")
																											baseExtra = visitableSource.getValue("baseExtra")
																											rentFlag = visitableSource.getValue("rentFlag")
															}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostGetTripInfo : BaseITWebAPIBody {
	
	//
									open var tripId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getTripInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getTripInfo"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let tripId_ = self.tripId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostGetTripInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"tripId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:tripId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"tripId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostGetTripInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetGetTripInfo : BaseITWebAPIBody {
	
	//
												open var requestTime:String?
    							open var bikeId:String?
    							open var hireStatus:String?
    							open var hireTime:String?
    							open var restoreTime:String?
    							open var hireStationId:String?
    							open var hireStationName:String?
    							open var hireParkNum:String?
    							open var hireCoord:String?
    							open var restoreStationId:String?
    							open var restoreStationName:String?
    							open var restoreParkNum:String?
    							open var restoreCoord:String?
    							open var money:String?
    							open var orderId:String?
    							open var orderStatus:String?
    							open var cityCode:String?
    							open var hLockType:String?
    							open var rLockType:String?
    							open var id:String?
    							open var reletId:String?
    							open var releteTime:String?
    							open var surplusSecond:String?
    							open var releteEndTime:String?
    							open var befDiscountMoney:String?
    							open var dispatchFee:String?
    							open var cardPreFee:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getTripInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/getTripInfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											requestTime = visitableSource.getValue("requestTime")
																											bikeId = visitableSource.getValue("bikeId")
																											hireStatus = visitableSource.getValue("hireStatus")
																											hireTime = visitableSource.getValue("hireTime")
																											restoreTime = visitableSource.getValue("restoreTime")
																											hireStationId = visitableSource.getValue("hireStationId")
																											hireStationName = visitableSource.getValue("hireStationName")
																											hireParkNum = visitableSource.getValue("hireParkNum")
																											hireCoord = visitableSource.getValue("hireCoord")
																											restoreStationId = visitableSource.getValue("restoreStationId")
																											restoreStationName = visitableSource.getValue("restoreStationName")
																											restoreParkNum = visitableSource.getValue("restoreParkNum")
																											restoreCoord = visitableSource.getValue("restoreCoord")
																											money = visitableSource.getValue("money")
																											orderId = visitableSource.getValue("orderId")
																											orderStatus = visitableSource.getValue("orderStatus")
																											cityCode = visitableSource.getValue("cityCode")
																											hLockType = visitableSource.getValue("hLockType")
																											rLockType = visitableSource.getValue("rLockType")
																											id = visitableSource.getValue("id")
																											reletId = visitableSource.getValue("reletId")
																											releteTime = visitableSource.getValue("releteTime")
																											surplusSecond = visitableSource.getValue("surplusSecond")
																											releteEndTime = visitableSource.getValue("releteEndTime")
																											befDiscountMoney = visitableSource.getValue("befDiscountMoney")
																											dispatchFee = visitableSource.getValue("dispatchFee")
																											cardPreFee = visitableSource.getValue("cardPreFee")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostCall : BaseITWebAPIBody {
	
	//
						open var phoneNumber:String?
    							open var orderId:String?
    							open var orderAmount:String?
    							open var orderState:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/external/callback"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/external/callback"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let phoneNumber_ = self.phoneNumber;
																					let orderId_ = self.orderId;
																					let orderAmount_ = self.orderAmount;
																					let orderState_ = self.orderState;
																					let type_ = self.type;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostCall",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"phoneNumber",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:phoneNumber_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"phoneNumber",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"orderId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"orderAmount",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:orderAmount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"orderAmount",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"orderState",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:orderState_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"orderState",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"type",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostCall",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetCall : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/external/callback"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/external/callback"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostCalculationFee : BaseITWebAPIBody {
	
	//
						open var cityCode:String?
    							open var bikeType:String?
    							open var serviceId:String?
    							open var appId:String?
    							open var hireDate:String?
    							open var restoreDate:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/calculationFee"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/calculationFee"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let cityCode_ = self.cityCode;
																					let bikeType_ = self.bikeType;
																					let serviceId_ = self.serviceId;
																					let appId_ = self.appId;
																					let hireDate_ = self.hireDate;
																					let restoreDate_ = self.restoreDate;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostCalculationFee",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:7,field:"bikeType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:7,value:bikeType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:7,field:"bikeType",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:7,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:7,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:7,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:7,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:7,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:7,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:7,field:"hireDate",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:7,value:hireDate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:7,field:"hireDate",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:7,field:"restoreDate",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:7,value:restoreDate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:7,field:"restoreDate",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostCalculationFee",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetCalculationFee : BaseITWebAPIBody {
	
	//
												open var money:String?
    							open var freeTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/calculationFee"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/calculationFee"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											money = visitableSource.getValue("money")
																											freeTime = visitableSource.getValue("freeTime")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostChangeUserStatus : BaseITWebAPIBody {
	
	//
						open var manageUserId:String?
    							open var manageUserName:String?
    							open var userId:String?
    							open var remark:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/changeUserStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/changeUserStatus"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let manageUserId_ = self.manageUserId;
																					let manageUserName_ = self.manageUserName;
																					let userId_ = self.userId;
																					let remark_ = self.remark;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostChangeUserStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"manageUserId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:manageUserId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"manageUserId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"manageUserName",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:manageUserName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"manageUserName",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"userId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:userId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"userId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"remark",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:remark_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"remark",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostChangeUserStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetChangeUserStatus : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/changeUserStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/changeUserStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostYearCardInvalid : BaseITWebAPIBody {
	
	//
						open var userIds:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/purchase/yearCardInvalid"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/purchase/yearCardInvalid"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let userIds_ = self.userIds;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostYearCardInvalid",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"userIds",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:userIds_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"userIds",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostYearCardInvalid",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetYearCardInvalid : BaseITWebAPIBody {
	
	//
												open var count:String?
    							open var closeTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/purchase/yearCardInvalid"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/purchase/yearCardInvalid"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											count = visitableSource.getValue("count")
																											closeTime = visitableSource.getValue("closeTime")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostYearCardPlaceAnOrder : BaseITWebAPIBody {
	
	//
									open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/purchase/yearCardPlaceAnOrder"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/purchase/yearCardPlaceAnOrder"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let orderId_ = self.orderId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostYearCardPlaceAnOrder",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"orderId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostYearCardPlaceAnOrder",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetYearCardPlaceAnOrder : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/purchase/yearCardPlaceAnOrder"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/purchase/yearCardPlaceAnOrder"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostOverNight : BaseITWebAPIBody {
	
	//
									open var bizType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/overNight"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/overNight"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let bizType_ = self.bizType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostOverNight",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"bizType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:bizType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"bizType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostOverNight",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetOverNight : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/overNight"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/overNight"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikecaPostSuppl : BaseITWebAPIBody {
	
	//
									open var appId:String?
    							open var serviceId:String?
    							open var terminalType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/suppl"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/suppl"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let appId_ = self.appId;
																					let serviceId_ = self.serviceId;
																					let terminalType_ = self.terminalType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikecaPostSuppl",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"terminalType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikecaPostSuppl",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikecaRetSuppl : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/suppl"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "37"
		self.appName_ = "bikeca"
		self.mapping_ = "/api/bikeca/business/suppl"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
